# © Copyright 1996-2012 ECMWF.
# 
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
# In applying this licence, ECMWF does not waive the privileges and immunities 
# granted to it by virtue of its status as an intergovernmental organisation nor
# does it submit to any jurisdiction.

!
! mars language definition file.
!
!     author.
!     -------
!
!           b.raoult 22/10/90
!
!     Modifications.
!     --------------
!
!           K. Fielding 26.07.93
!           Add new observation types wind profile (WP) and
!           temp mobile (TM)
!
!
! syntax :
!
!
!  command name ; command description ; command type     
!  {
!        parameter 1
!        {
!       value 1 ; abbreviation 1
!               value 2 ; abbreviation 2
!               value 3 
!               ...
!               value n ; abbreviation n
!    } = default value
!
!        parameter 2
!        {
!            ...
!        } = default value
!       
!        ...
!
! }
!
!------------------------------------------------------------------------

_DUMMY ; DUMMY REQUEST  ; DUMMY
{
    PARAM {


20 DEGREES ISOTHERM DEPTH                     ;  20D   ;  163
ACCUMULATED CLOUD FRACTION TENDENCY           ;  ACF   ;  241
ACCUMULATED ICE WATER TENDENCY                ;  AIW   ;  249
ACCUMULATED LIQUID WATER TENDENCY             ;  ALW   ;  242
ACCUMULATED CARBON DIOXIDE NET ECOSYSTEM EXCHANGE   ; ACO2NEE; 80.228
ACCUMULATED CARBON DIOXIDE GROSS PRIMARY PRODUCTION ; ACO2GPP; 81.228
ACCUMULATED CARBON DIOXIDE ECOSYSTEM RESPIRATION    ; ACO2REC; 82.228
ACCUMULATED FREEZING RAIN                     ;  FZRA  ;  228216
ADIABATIC TENDENCY OF HUMIDITY                ;  ATH   ;  229
ADIABATIC TENDENCY OF HUMIDITY - ECMWF        ;  ATHE  ;  252
ADIABATIC TENDENCY OF MERIDIONAL WIND         ;  ATMW  ;  254
ADIABATIC TENDENCY OF MERIDIONAL WIND - ASTEX ; ATMWAX ;  231
ADIABATIC TENDENCY OF TEMPERATURE             ;  ATT   ;  228
ADIABATIC TENDENCY OF TEMPERATURE - ECMWF     ;  ATTE  ;  251
ADIABATIC TENDENCY OF ZONAL WIN               ;  ATZW  ;  230
ADIABATIC TENDENCY OF ZONAL WIND - ECMWF      ;  ATZE  ;  253
ALBEDO                                        ;  AL    ;  174
ALTIMETER WAVE HEIGHT                         ;  AWH   ;  246
ALTIMETER CORRECTED WAVE HEIGHT               ;  ACWH  ;  247
ALTIMETER RANGE RELATIVE CORRECTION           ;  ARRC  ;  248
ALTITUDE OF EMITTER                           ;  ALE   ;  210119 ; 119.210
ALTITUDE OF PLUME TOP                         ;  ALPT  ;  210120 ; 120.210
ANALYSED POTENTIAL TEMPERATURE                ;  APT   ;  181
ANALYSED SALINITY                             ;  AS    ;  183
ANGLE OF SUBGRID OROGRAPHY                    ;  ANOR  ;  162
ANISOTROPHY SUBGRID OROGRAPHY                 ;  ISOR  ;  161
APPARENT SURFACE HUMIDITY                     ;  ASQ   ;  233
ATMOSPHERIC TIDE                              ;  AT    ;  127
AVERAGE POTENTIAL TEMPERATURE IN UPPER 300M   ; TAV300 ;  164
AVERAGE SALINITY IN UPPER 300M                ; SAV300 ;  175
BACKGROUND POTENTIAL TEMPERATURE              ;  BPT   ;  180
BENJAMIN-FEIR INDEX                           ;  BFI   ;  253
BOUNDARY LAYER DISSIPATION                    ;  BLD   ;  145
BOUNDARY LAYER HEIGHT                         ;  BLH   ;  159
BRIGHTNESS TEMPERATURE                        ;  BTMP  ;  194
BUDGET VALUES                                 ;  BV    ;  128
CHANGE FROM REMOVING NEG. HUMID               ;  CRNH  ;  227
CHARNOCK                                      ;  CHNK  ;  148
CLEAR SKY SURFACE PHOTOSYNTHETICALLY ACTIVE RADIATION  ; PARCS ; 20
CLIMAT. DEEP SOIL TEMP.                       ;  CDST  ;  183
CLIMAT. DEEP SOIL WETNESS                     ;  CDSW  ;  184
CLOUD BASE HEIGHT                             ;  CBH   ;  228023   ; 23.228
CLOUD COVER                                   ;  CC    ;  248
CLOUD FRACTION                                ;  CF    ;  213
CLOUD ICE WATER CONTENT                       ;  CIWC  ;  247
CLOUD LIQUID WATER                            ;  CLW   ;  212
CLOUD LIQUID WATER CONTENT                    ;  CLWC  ;  246
CLOUD LIQUID WATER CONTENT - ERA              ; CLWCER ;  241
CLOUD RAIN WATER CONTENT                      ;  CRWC  ;  75
CLOUD SNOW WATER CONTENT                      ;  CSWC  ;  76
CLOUDY BRIGHTNESS TEMPERATURE                 ;  CLBT  ; 260510
COEFFICIENT OF DRAG WITH WAVES                ;  CDWW  ;  233
CONVECTIVE AVAILABLE POTENTIAL ENERGY         ;  CAPE  ;  059
CONVECTIVE AVAILABLE POTENTIAL ENERGY SHEAR   ;  CAPES ;  228044
CONVECTIVE CLOUD COVER                        ;  CCC   ;  185
CONVECTIVE INHIBITION                         ;  CIN   ;  228001
CONVECTIVE PRECIPITATION                      ;  CP    ;  143
CONVECTIVE SNOW-FALL                          ;  CSF   ;  239
CONVECTIVE RAIN RATE                          ;  CRR   ;  228218
CONVECTIVE TENDENCY OF MERIDIONAL WIND        ;  CTMW  ;  223
CONVECTIVE TENDENCY OF ZONAL WIND             ;  CTZW  ;  222
DEEP SOIL TEMPERATURE                         ;  DST   ;  170
DEEP SOIL WETNESS                             ;  DSW   ;  171
DEPTH OF SALINITY MAXIMUM                     ;  DSMAX ;  174
DEPTH OF VELOCITY MAXIMUM                     ;  DUMAX ;  172
DIABATIC HEATING BY CUMULUS CONVECTION        ;  DHCC  ;  216
DIABATIC HEATING BY LARGE-SCALE CONDENSATION  ;  DHLC  ;  217
DIABATIC HEATING BY RADIATION                 ;  DHR   ;  214
DIABATIC HEATING BY VERTICAL DIFFUSION        ;  DHVD  ;  215
DIRECT SOLAR RADIATION                        ;  DSRP  ;  047
DIVERGENCE                                    ;  D     ;  155
DOWNWARD UV RADIATION AT THE SURFACE          ;  UVB   ;  057
DUCT BASE HEIGHT                              ;  DCTB  ;  228017   ; 017.228
EASTWARD GRAVITY WAVE SURFACE STRESS          ;  LGWS  ;  195
EASTWARD TURBULENT SURFACE STRESS             ;  EWSS  ;  180
E-W OROGRAPHIC VARIANCE.                      ;  EWOV  ;  190
EQUIVALENT POTENTIAL TEMPERATURE              ;  EQPT  ;  004
ETA-COORDINATE VERTICAL VELOCITY              ;  ETADOT ; 077
EVAPORATION                                   ;  E     ;  182
EW GRAVITY WAVE DRAG                          ;  EWGD  ;  220
FIELD CAPACITY                                ;  CAP   ;  228170 ; 170.228
FLUX OF CARBON DIOXIDE NET ECOSYSTEM EXCHANGE       ; FCO2NEE; 83.228
FLUX OF CARBON DIOXIDE GROSS PRIMARY PRODUCTION     ; FCO2GPP; 84.228
FLUX OF CARBON DIOXIDE ECOSYSTEM RESPIRATION        ; FCO2REC; 85.228
FORECAST ALBEDO                               ;  FAL   ;  243
FORECAST LOG SRF ROUGHNESS HEAT               ;  FLSR  ;  245
FORECAST SURFACE ROUGHNESS                    ;  FSR   ;  244
FRICTION VELOCITY                             ;  ZUST  ;  228003 ; 3.228
GEOPOTENTIAL                                  ;  Z     ;  129
GEOPOTENTIAL ANOMALY                          ;  ZA    ;  129.171
GRAVITY WAVE DISSIPATION.                     ;  GWD   ;  197
HEIGHT GEOPOTENTIAL                           ;  GH    ;  156
HIGH CLOUD COVER                              ;  HCC   ;  188
HIGH VEGETATION COVER                         ;  CVH   ;  028
HORIZONTAL VISIBILITY                         ;  HVIS  ;  228025  ; 25.228
HUMIDITY TENDENCY BY CUMULUS CONVECTION       ;  HTCC  ;  225
HUMIDITY TENDENCY BY LARGE-SCALE CONDENSATION ;  HTLC  ;  226
HUNDRED METRE U WIND COMPONENT                ;  100U  ;  U100 ; 228246  ;  246.228
HUNDRED METRE V WIND COMPONENT                ;  100V  ;  V100 ; 228247  ;  247.228
HUNDRED METRE WIND SPEED                      ;  100SI ;  228249  ;  249.228
ICE AGE                                       ;  ICE   ;  250
ICE SURFACE TEMPERATURE LAYER 1               ;  IST1  ; ISTL1 ;  035
ICE SURFACE TEMPERATURE LAYER 2               ;  IST2  ; ISTL2 ;  036
ICE SURFACE TEMPERATURE LAYER 3               ;  IST3  ; ISTL3 ;  037
ICE SURFACE TEMPERATURE LAYER 4               ;  IST4  ; ISTL4 ;  038
INSTANT MOISTURE FLUX                         ;  IE    ;  232
INSTANTANEOUS EASTWARD TURBULENT SURFACE STRESS   ;  IEWS  ; 229
INSTANTANEOUS NORTHWARD TURBULENT SURFACE STRESS   ;  INSS  ; 230
INSTANTANEOUS SURFACE SENSIBLE HEAT FLUX      ;  ISHF  ;  231
K INDEX                                       ;  KX    ;  260121
LAKE COVER                                    ;  CL    ;   26
LAKE DEPTH                                    ;  DL    ;  228007 ;  7.228
LAKE MIX-LAYER TEMPERATURE                    ;  LMLT  ;  228008 ;  8.228
LAKE MIX-LAYER DEPTH                          ;  LMLD  ;  228009 ;  9.228
LAKE BOTTOM TEMPERATURE                       ;  LBLT  ;  228010 ; 10.228
LAKE TOTAL LAYER TEMPERATURE                  ;  LTLT  ;  228011 ; 11.228
LAKE SHAPE FACTOR                             ;  LSHF  ;  228012 ; 12.228
LAKE ICE TEMPERATURE                          ;  LICT  ;  228013 ; 13.228
LAKE ICE DEPTH                                ;  LICD  ;  228014 ; 14.228
LAND SEA MASK                                 ;  LSM   ;  172
LARGE SCALE PRECIPITATION                     ;  LSP   ;  142
LARGE SCALE PRECIPITATION FRACTION            ;  LSPF  ;  050
LARGE SCALE SNOW-FALL                         ;  LSF   ;  240
LARGE SCALE SNOWFALL RATE WATER EQUIVALENT    ;  LSSFR ;  228221
LEAF AREA INDEX LOW VEGETATION                ;  LAILV ;   66
LEAF AREA INDEX HIGH VEGETATION               ;  LAIHV ;   67
LN SURFACE PRESSURE                           ;  LNSP  ;  152
LOG SURFACE ROUGHNESS - HEAT                  ;  LSRH  ;  234
LONG WAVE HEATING RATE                        ;  LWH   ;  154
LOW CLOUD COVER                               ;  LCC   ;  186
LOW VEGETATION COVER                          ;  CVL   ;  027
MAGNITUDE OF SURFACE STRESS                   ;  MAGSS ;  048
MAXIMUM TEMPERATURE AT 2M                     ;  MX2T  ;  201
MAXIMUM TEMPERATURE AT 2M ANOMALY             ;  MX2TA  ;  201.171
MAXIMUM TEMPERATURE AT 2M INDEX               ;  MX2TI ;  201.132
MAXIMUM TEMPERATURE AT 2M IN THE LAST 6 HOURS ANOMALY  ;  MX2T6A  ;  121.171
MAXIMUM TEMPERATURE AT 2M IN THE LAST 6 HOURS  ;  MX2T6 ;  121.128
MAXIMUM TEMPERATURE AT 2M IN THE LAST 3 HOURS  ;  MX2T3 ;  228026 ; 026.228
MAXIMUM TEMPERATURE AT 2M IN THE LAST 24 HOURS ;  MX2T24 ;  51
MAXIMUM TOTAL PRECIPITATION RATE IN THE LAST 3 HOURS  ; MXTPR3  ; 228222
MAXIMUM TOTAL PRECIPITATION RATE IN THE LAST 6 HOURS  ; MXTPR6  ; 228224
MAXIMUM INDIVIDUAL WAVE HEIGHT                           ;  HMAX  ;  218
MAXIMUM OF SIGNIFICANT WAVE HEIGHT            ;  MAXSWH ; 200
MEAN 2 METRE TEMPERATURE PAST 24 HOURS        ;  MEAN2T24;  055
MEAN 2 METRE DEWPOINT TEMPERATURE PAST 24 HOURS ;  MEAN2D24;  056
MEAN TEMPERATURE AT 2 METRES                  ;  MEAN2T ; 228004  ; 4.228
MEAN DIRECTION OF TOTAL SWELL               ;  MDPS ; MDTS ;  238
MEAN DIRECTION OF WIND WAVES                  ;  MDWW  ;  235
MEAN OF 10M WINDSPEED                         ;  MU10  ;  241
MEAN 10 METRE WINDSPEED                       ;  MEAN10WS ; 228005  ; 5.228
MEAN TOTAL CLOUD COVER                        ;  MEANTCC ; 228006   ; 6.228
MEAN PERIOD                                   ;  MP    ;  232
MEAN PERIOD OF TOTAL SWELL                  ;  MPPS ; MPTS  ;  239
MEAN PERIOD OF WIND WAVES                     ;  MPWW  ;  236
MEAN SEA LEVEL PRESSURE                       ;  MSL   ; MSLP ;  151
MEAN SEA LEVEL PRESSURE ANOMALY               ;  MSLA   ; MSLPA ;  151.171
MEAN SEA LEVEL PRESSURE SIGNIFICANCE          ;  MSLS  ;  151.234
MEAN SEA LEVEL PRESSURE ANOMALY OF AT LEAST 0 Pa ;  MSLAG0   ;  10
MEAN SQUARE SLOPE OF WAVES                    ;  MSQS  ;  244
MEAN VERTICAL GRADIENT OF REFRACTIVITY INSIDE TRAPPING LAYER ; DNDZA ;  228016  ; 016.228
MEAN VERTICAL VELOCITY                        ;  MVV   ;  232
MEAN WAVE DIRECTION                           ;  MWD   ;  230
MEAN WAVE DIRECTION OF FIRST SWELL PARTITION     ;  MWD1 ;    122 
MEAN WAVE DIRECTION OF SECOND SWELL PARTITION    ;  MWD2 ;    125 
MEAN WAVE DIRECTION OF SWELL THIRD PARTITION     ;  MWD3 ;    128 
MEAN WAVE PERIOD OF FIRST SWELL PARTITION        ;  MWP1 ;    123 
MEAN WAVE PERIOD OF SECOND SWELL PARTITION       ;  MWP2 ;    126 
MEAN WAVE PERIOD OF SWELL THIRD PARTITION        ;  MWP3 ;    129 
MEAN WAVE PERIOD                              ;  MWP   ;  232
MEAN WAVE PERIOD PROBABILITY                  ;  MWPP  ;  232
MEAN WAVE PERIOD BASED ON FIRST MOMENT                 ; MP1   ; 220
MEAN WAVE PERIOD BASED ON FIRST MOMENT FOR SWELL       ; P1PS  ; 226
MEAN WAVE PERIOD BASED ON FIRST MOMENT FOR WIND WAVES  ; P1WW  ; 223
MEAN WAVE PERIOD BASED ON SECOND MOMENT                ; MP2   ; 221
MEAN WAVE PERIOD BASED ON SECOND MOMENT FOR SWELL      ; P2PS  ; 227
MEAN WAVE PERIOD BASED ON SECOND MOMENT FOR WIND WAVES ; P2WW  ; 224
MEAN WIND DIRECTION                           ;  MDWI  ;  242
MEDIUM CLOUD COVER                            ;  MCC   ;  187
MINIMUM TEMPERATURE AT 2M                     ;  MN2T  ;  202
MINIMUM TEMPERATURE AT 2M ANOMALY             ;  MN2TA  ;  202.171
MINIMUM TEMPERATURE AT 2M INDEX               ;  MN2TI ;  202.132 
MINIMUM TEMPERATURE AT 2M IN THE LAST 6 HOURS ANOMALY  ;  MN2T6A  ;  122.171
MINIMUM TEMPERATURE AT 2M IN THE LAST 6 HOURS  ;  MN2T6 ;  122.128
MINIMUM TEMPERATURE AT 2M IN THE LAST 3 HOURS  ;  MN2T3 ;  228027 ; 027.228
MINIMUM TEMPERATURE AT 2M IN THE LAST 24 HOURS ;  MN2T24 ;  52
MINIMUM TOTAL PRECIPITATION RATE IN THE LAST 3 HOURS  ; MNTPR3  ; 228223
MINIMUM TOTAL PRECIPITATION RATE IN THE LAST 6 HOURS  ; MNTPR6  ; 228225
MINIMUM VERTICAL GRADIENT OF REFRACTIVITY INSIDE TRAPPING LAYER ; DNDZN ; 228015 ; 015.228
MODEL BATHYMETRY                              ;  WMB   ;  219
MONTGOMERY POTENTIAL                          ;  MONT  ;  053
NORMALIZED ENERGY FLUX INTO WAVES             ;  PHIAW ;  211
NORMALIZED ENERGY FLUX INTO OCEAN             ;  PHIOC ;  212
NORMALIZED STRESS INTO OCEAN                  ;  TAUOC ;  214
NORTHWARD GRAVITY WAVE SURFACE STRESS         ;  MGWS  ;  196
NORTHWARD TURBULENT SURFACE STRESS            ;  NSSS  ;  181
N-S OROGRAPHIC VARIANCE                       ;  NSOV  ;  191
NE-SW OROGRAPHIC VARIANCE                     ;  NWOV  ;  192
NS GRAVITY WAVE DRAG                          ;  NSGD  ;  221
NEAR IR ALBEDO FOR DIRECT RADIATION           ;  ALNIP ;   17
NEAR IR ALBEDO FOR DIFFUSE RADIATION          ;  ALNID ;   18
NEUTRAL WIND AT 10 M X-COMPONENT              ;  U10N  ;  228131  ; 131.228
NEUTRAL WIND AT 10 M Y-COMPONENT              ;  V10N  ;  228132  ; 132.228
NW-SE OROGRAPHIC VARIANCE                     ;  NEOV  ;  193
OBSERVATION COUNT                             ;  OBCT  ;  062
OCEAN POTENTIAL TEMPERATURE                   ;  OCPT  ;  129
OCEAN CURRENT ZONAL COMPONENT                 ;  OCU   ;  131.151
OCEAN CURRENT MERIDIONAL COMPONENT            ;  OCV   ;  132.151
OZONE MASS MIXING RATIO                       ;  O3    ;  203     ; 203.128
PEAK DIRECTION                                ;  PD    ;  230
PEAK PERIOD                                   ;  PP    ;  231
PEAK PERIOD OF 1D SPECTRA                     ;  PP1D  ;  231
PERIOD CORRESPONDING TO MAXIMUM INDIVIDUAL WAVE HEIGHT   ;  TMAX  ;  217
PHOTOSYNTHETICALLY ACTIVE RADIATION AT THE SURFACE ;  PAR   ;  058
PROBABILITY OF A TROPICAL STORM                     ; PTS   ; 89.131
PROBABILITY OF A HURRICANE                          ; PH    ; 90.131
PROBABILITY OF A TROPICAL DEPRESION                 ; PTD   ; 91.131
CLIMATOLOGICAL PROBABILITY OF A TROPICAL STORM      ; CPTS  ; 92.131
CLIMATOLOGICAL PROBABILITY OF A HURRICANE           ; CPH   ; 93.131
CLIMATOLOGICAL PROBABILITY OF A TROPICAL DEPRESION  ; CPTD  ; 94.131
PROBABILITY ANOMALY OF A TROPICAL STORM             ; PATS  ; 95.131
PROBABILITY ANOMALY OF A HURRICANE                  ; PAH   ; 96.131
PROBABILITY ANOMALY OF A TROPICAL DEPRESION         ; PATD  ; 97.131
POTENTIAL EVAPORATION                         ;  PEV   ;  228251
POTENTIAL TEMPERATURE                         ;  PT    ;  003
POTENTIAL TEMPERATURE INCREMENT               ;  PTI   ;  178
POTENTIAL TEMPERATURE ANALYSIS ERROR          ;  PTAE  ;  179
POTENTIAL TEMPERATURE BACKGROUND ERROR        ;  PTBE  ;  182
POTENTIAL VORTICITY                           ;  PV    ;  060
PRECIP. ANALYSIS WEIGHTS                      ;  PAW   ;  204
PRECIPITABLE WATER CONTENT                    ;  PWC   ;  137
PRECIPITATION TYPE                            ;  PTYPE ; 260015
PRESSURE                                      ;  PRES  ;  054
RELATIVE HUMIDITY                             ;  R     ;  157
RUNOFF                                        ;  RO    ;  205
SALINITY INCREMENT                            ;  SALI  ;  184
SALINITY MAXIMUM                              ;  SMAX  ;  173
SATURATED EQUIVALENT POTENTIAL TEMPERATURE    ;  SEPT  ;  005
SATURATION                                    ;  SAT   ;  228172  ;  172.228
SEA ICE COVER                                 ;  CI    ;  031
SEA LEVEL PREVIOUS TIMESTEP                   ;  SL_1  ;  146
SEA SURFACE TEMPERATURE                       ;  SSTK  ;  SST   ; 034
SEA SURFACE TEMPERATURE ANOMALY               ;  SSTAK ;  SSTA  ; 171034  ; 034.171
SHORT WAVE HEATING RATE                       ;  SWHR  ;  153
SIGNIFICANT HEIGHT TOTAL SWELL              ;  SHPS ; SHTS  ;  237
SIGNIFICANT HEIGHT WIND WAVES                 ;  SHWW  ;  234
SIGNIFICANT WAVE HEIGHT                       ;  SWH   ;  229
SIGNIFICANT WAVE HEIGHT PROBABILITY           ;  SWHP  ;  229
SIGNIFICANT WAVE HEIGHT OF FIRST SWELL PARTITION ;  SWH1 ;    121
SIGNIFICANT WAVE HEIGHT OF SECOND SWELL PARTITION;  SWH2 ;    124
SIGNIFICANT WAVE HEIGHT OF SWELL THIRD PARTITION ;  SWH3 ;    127
SIGNIFICANT WAVE HEIGHT OF ALL WAVES WITH PERIOD LARGER THAN 10S  ; SH10  ; 120
SKIN RESERVOIR CONTENT                        ;  SRC   ;  198
SKIN TEMPERATURE                              ;  SKT   ;  235
SLOPE OF SUBGRID OROGRAPHY                    ;  SLOR  ;  163
SNOW ALBEDO                                   ;  ASN   ;  032
SNOW DENSITY                                  ;  RSN   ;  033
SNOW DENSITY ANOMALY                          ;  RSNA  ;  171033  ; 033.171
SNOW DEPTH                                    ;  SD    ;  141
SNOW DEPTH ANOMALY                            ;  SDA   ;  171141  ; 141.171
SNOW EVAPORATION                              ;  ES    ;  044
SNOWFALL                                      ;  SF    ;  144
SNOWFALL INDEX                                ;  SFI   ;  144.132
SNOWFALL PROBABILITY                          ;  SFP   ;  144
SNOWFALL ANOMALOUS RATE OF ACCUMULATION       ;  SFARA ;  144.173
SNOWMELT                                      ;  SMLT  ;  045
SOIL SAND FRACTION                            ;  SSFR  ;    6
SOIL CLAY FRACTION                            ;  SCFR  ;    7
SOIL TEMPERATURE LEVEL 1                      ;  STL1  ;  139
SOIL TEMPERATURE ANOMALY LEVEL 1              ;  STAL1 ;  139.171
SOIL TEMPERATURE LEVEL 2                      ;  STL2  ;  170
SOIL TEMPERATURE LEVEL 3                      ;  STL3  ;  183
SOIL TEMPERATURE LEVEL 4                      ;  STL4  ;  236
SOIL TYPE                                     ;  SLT   ;  043
SOIL WETNESS LEVEL 1                          ;  SWL1  ;  140
SOIL WETNESS LEVEL 2                          ;  SWL2  ;  171
SOIL WETNESS LEVEL 3                          ;  SWL3  ;  184
SOIL WETNESS LEVEL 4                          ;  SWL4  ;  237
SOLAR DURATION                                ;  SDUR  ;  046
SOLAR INSULATION                              ;  SI    ;  212
SPECIFIC HUMIDITY                             ;  Q     ;  133
STANDARD DEVIATION 10M WIND SPEED             ;  SDU   ;  243
STANDARD DEVIATION OROGRAPHY                  ;  SDOR  ;  160
STANDARD DEVIATION OF FILTERED SUBGRID OROGRAPHY  ;  SDFOR  ;  74.128
STANDARD DEVIATION WAVE HEIGHT                ;  SDHS  ;  240
STREAM FUNCTION                               ;  STRF  ;  001
STREAM FUNCTION ANOMALY                       ;  STRFA  ;  001.171
SUB-SURFACE RUNOFF                            ;  SSRO  ;    9
SUNSHINE DURATION                             ;  SUND  ;  189
SUNSHINE DURATION ANOMALY                     ;  SUNDA ;  189.171
SUNSHINE DURATION ANOMALOUS RATE OF ACCUMULATION ;  SUNDARA ;  189.173
SURFACE LATENT HEAT FLUX                      ;  SLHF  ;  147
SURFACE NET RADIATION                         ;  SNR   ;  149
SURFACE NET SOLAR RADIATION CLEAR SKY         ;  SSRC  ;  210
SURFACE NET THERMAL RADIATION CLEAR SKY       ;  STRC  ;  211
SURFACE PRESSURE                              ;  SP    ;  134
SURFACE ROUGHNESS                             ;  SR    ;  173
SURFACE RUNOFF                                ;  SRO   ;    8
SURFACE SENSIBLE HEAT FLUX                    ;  SSHF  ;  146
SURFACE SOIL WETNESS                          ;  SSW   ;  140
SURFACE SOLAR RADIATION                       ;  SSR   ;  176
SURFACE SOLAR RADIATION DOWNWARDS             ;  SSRD  ;  169
SURFACE STRESS                                ;  SS    ;  148
SURFACE TEMPERATURE                           ;  ST    ;  139
SURFACE TEMPERATURE ANOMALY OF AT LEAST 0K    ;  STAG0 ;    9
SURFACE TEMPERATURE SIGNIFICANCE              ;  STS   ;  139.234
SURFACE NET THERMAL RADIATION                     ;  STR   ;  177
SURFACE THERMAL RADIATION DOWNWARDS           ;  STRD  ;  175
TEMPERATURE                                   ;  T     ;  130
TEMPERATURE ANOMALY                           ;  TA    ;  130.171
TEMPERATURE ANOMALY PROBABILITY               ;  TAP   ;  130
TEMPERATURE OF SNOW LAYER                     ;  TSN   ;  238
TEN METRE SPEED PROBABILITY                   ;  10SP  ;  165
TEN METRE WIND SPEED INDEX                    ;  10WSI ;  165
TEN METRE U WIND COMPONENT                    ;  10U   ;  165
TEN METRE U WIND COMPONENT ANOMALY            ;  10UA   ;  165.171
TEN METRE V WIND COMPONENT                    ;  10V   ;  166
TEN METRE V WIND COMPONENT ANOMALY            ;  10VA   ;  166.171
TEN METRE WINDSPEED IRRESP OF DIR             ;  10SI  ;  207
TEN METRE WINDSPEED ONLY                      ;  10WS  ;  246
TEN METRE WIND DIRECTION                      ;  DWI   ;  249
TENDENCY SURFACE PRESSURE                     ;  TSP   ;  158
# THICKNES is derived parameter in ProdGen - thicknes of the layer 1000/500 or 850/500 . Not available in MARS
THICKNES                                      ;  THK ; 928
TOP NET RADIATION                             ;  TNR   ;  150
TOP NET SOLAR RADIATION CLEAR SKY             ;  TSRC  ;  208
TOP SOLAR RAD. UPWARD CLEAR SKY               ;  TSUC  ;  210
TOP NET SOLAR RADIATION                           ;  TSR   ;  178
TOP SOLAR RADIATION UPWARD                    ;  TSRU  ;  130208
TOP THERMAL RAD. UPWARD CLEAR SKY             ;  TTUC  ;  211
TOA INCIDENT SOLAR RADIATION                  ;  TISR  ;  212
TOP NET THERMAL RADIATION                         ;  TTR   ;  179
TOP THERMAL RADIATION UPWARD                  ;  TTRU  ;  130209
TOP UPWARD THERMAL RADIATION CLEAR SKY        ;  TTRC  ;  209
TOTAL CLOUD COVER                             ;  TCC   ;  164
TOTAL CLOUD COVER ANOMALY                     ;  TCCA   ;  164.171
TOTAL COLUMN ICE WATER                        ;  TCIW  ;  079.128
VERTICAL INTEGRAL OF DIVERGENCE OF COULD LIQUID WATER FLUX ;  VILWD  ;  079.162
TOTAL COLUMN ICE WATER ANOMALY                ;  TCIWA  ;  079.171
TOTAL COLUMN LIQUID WATER                     ;  TCLW  ;  078.128
VERTICAL INTEGRAL OF NORTHWARD OZONE FLUX     ;  VIOZN  ;  078.162
TOTAL COLUMN LIQUID WATER ANOMALY             ;  TCLWA  ;  078.171
TOTAL COLUMN OZONE                            ;  TCO3  ;  206     ; 206.128
TOTAL COLUMN RAIN WATER                       ;  TCRW  ; 228089   ; 089.228
TOTAL COLUMN SNOW WATER                       ;  TCSW  ; 228090   ; 090.228
TOTAL COLUMN WATER                            ;  TCW   ;  136
TOTAL COLUMN WATER ANOMALY                    ;  TCWA  ;  136.171
TOTAL COLUMN WATER VAPOUR                     ;  TCWV  ;  137
TOTAL COLUMN WATER VAPOUR ANOMALY             ;  TCWVA ;  137.171
TOTAL PRECIPITATION                           ;  TP    ;  228
TOTAL PRECIPITATION ANOMALY                   ;  TPA    ;  228.171
TOTAL PRECIPITATION ANOMALOUS RATE OF ACCUMULATION ;  TPARA    ;  228.173
TOTAL PRECIPITATION INDEX                     ;  TPI   ;  228
TOTAL PRECIPITATION PROBABILITY               ;  TPP   ;  228
TOTAL PRECIPITATION SIGNIFICANCE              ;  TPS   ;  228.234
TOTAL PRECIPITATION ANOMALY OF AT LEAST 20 MM ;  TPAG20;    6
TOTAL PRECIPITATION ANOMALY OF AT LEAST 10 MM ;  TPAG10;    7
TOTAL PRECIPITATION ANOMALY OF AT LEAST  0 MM ;  TPAG0 ;    8
TOTAL TOTALS INDEX                            ;  TOTALX ; 260123
TOTAL SKY DIRECT SOLAR RADIATION AT SURFACE   ;  FDIR ;   228021
TRAPPING LAYER BASE HEIGHT                    ;  TPLB  ;  228018   ;  018.228
TRAPPING LAYER TOP HEIGHT                     ;  TPLT  ;  228019   ; 019.228
TWO HUNDRED METRE U WIND COMPONENT            ;  200U  ;  228239  ;  239.228
TWO HUNDRED METRE V WIND COMPONENT            ;  200V  ;  228240  ;  240.228
TWO HUNDRED METRE WIND SPEED                  ;  200SI ;  228241  ;  241.228
TWO METRE DEWPOINT                            ;  2D    ;  168
TWO METRE DEWPOINT ANOMALY                    ;  2DA   ;  171168   ; 168.171
TWO METRE TEMPERATURE                         ;  2T    ;  167
TWO METRE TEMPERATURE INDEX                   ;  2TI   ;  167
TWO METRE TEMPERATURE PROBABILITY             ;  2TP   ;  167
TWO METRE TEMPERATURE ANOMALY                 ;  2TA   ;  167.171
TWO METRE TEMPERATURE SIGNIFICANCE            ;  2TS   ;  167.234
TWO METRE TEMPERATURE WARM ANOMALY OF AT LEAST 2K    ;  2TWA2K;    1
TWO METRE TEMPERATURE WARM ANOMALY OF AT LEAST 1K    ;  2TWA1K;    2
TWO METRE TEMPERATURE WARM ANOMALY OF AT LEAST 0K    ;   2TWA0K;    3
TWO METRE TEMPERATURE COLD ANOMALY OF AT LEAST 1K    ;  2TCA1K;    4
TWO METRE TEMPERATURE COLD ANOMALY OF AT LEAST 2K    ;  2TCA2K;    5
TWO-D WAVE SPECTRA                            ;  2DSP  ;  250
TWO-D WAVE SINGLE FREQUENCY DIRECTION SPECTRUM;  2DFD  ;  251
TYPE OF HIGH VEGETATION                       ;  TVH   ;  030
TYPE OF LOW VEGETATION                        ;  TVL   ;  029
U WIND COMPONENT                              ;  U     ;  131
U WIND COMPONENT ANOMALY                      ;  UA    ;  131.171
U-COMPONENT OF DIVERGENT WIND                 ;  UDVW  ;  011
U-COMPONENT OF ROTATIONAL WIND                ;  URTW  ;  013
U-COMPONENT STOKES DRIFT                      ;  UST   ;  215
UNBALANCED COMPONENT OF DIVERGENCE            ;  UCDV  ;  023
UNBALANCED COMPONENT OF TEMPERATURE           ;  UCTP  ;  021
UNBALANCED COMPONENT OF LNSP                  ;  UCLN  ;  022
U-VELOCITY MAXIMUM                            ;  UMAX  ;  171
UV VISIBLE ALBEDO FOR DIRECT RADIATION        ;  ALUVP ;   15
UV VISIBLE ALBEDO FOR DIFFUSE RADIATION       ;  ALUVD ;   16
V WIND COMPONENT                              ;  V     ;  132
V WIND COMPONENT ANOMALY                      ;  VA    ;  132.171
V-COMPONENT OF DIVERGENT WIND                 ;  VDVW  ;  012
V-COMPONENT OF ROTATIONAL WIND                ;  VRTW  ;  014
V-COMPONENT STOKES DRIFT                      ;  VST   ;  216
VARIANCE SUBGRIDSCALE OROGRAPHY               ;  VSO   ;  200
VEGETATION                                    ;  VEG   ;  199
VELOCITY POTENTIAL                            ;  VPOT  ;  002
VELOCITY POTENTIAL ANOMALY                    ;  VPOTA ;  002.171
VERTICAL DIFFUSION OF HUMIDITY                ;  VDH   ;  224
VERTICAL DIFFUSION OF MERIDIONAL WIND         ;  VDMW  ;  219
VERTICAL DIFFUSION OF ZONAL WIND              ;  VDZW  ;  218
VERTICAL VELOCITY                             ;  W     ;  135
VERTICALLY INTEGRATED MERIDIONAL HEAT TRANSPORT    ;  MHT   ;  170
VERTICALLY INTEGRATED MERIDIONAL VOLUME TRANSPORT  ;  MTR   ;  168
VERTICALLY INTEGRATED MOISTURE DIVERGENCE     ;  VIMD  ;  213
VERTICALLY INTEGRATED ZONAL HEAT TRANSPORT         ;  ZHT   ;  169
VERTICALLY INTEGRATED ZONAL VOLUME TRANSPORT       ;  ZTR   ;  167
VOLUMETRIC SOIL WATER LAYER 1                 ;  SWV1  ; SWVL1 ;  039
VOLUMETRIC SOIL WATER LAYER 2                 ;  SWV2  ; SWVL2 ;  040
VOLUMETRIC SOIL WATER LAYER 3                 ;  SWV3  ; SWVL3 ;  041
VOLUMETRIC SOIL WATER LAYER 4                 ;  SWV4  ; SWVL4 ;  042
VORTICITY                                     ;  VO    ;  138
WAVE HEIGHT                                   ;  WH    ;  229
WAVE SPECTRAL DIRECTIONAL WIDTH               ;  WDW   ; 222
WAVE SPECTRAL DIRECTIONAL WIDTH FOR SWELL     ;  DWPS  ; 228
WAVE SPECTRAL DIRECTIONAL WIDTH FOR WIND WAVES;  DWWW  ; 225
WAVE SPECTRAL KURTOSIS                        ;  WSK   ; 252
WAVE SPECTRAL PEAKEDNESS                      ;  WSP   ; 254
WAVE SPECTRAL SKEWNESS                        ;  WSS   ; 207 
WILTING POINT                                 ;  WILT  ; 228171  ; 171.228
WIND GUST AT 10 METRES                        ;  10FG  ;  049
WIND GUST AT 10 METRES INDEX                  ;  10FGI ;  049
WIND GUST AT 10 METRES IN THE LAST 6 HOURS     ;  10FG6 ;  123.128
WIND GUST AT 10 METRES IN THE LAST 3 HOURS     ;  10FG3 ;  228028 ; 028.228
INSTANTANEOUS 10 METRE WIND GUST              ;  I10FG  ;  228029
WIND SPEED                                    ;  WS    ;   10
ZERO DEGREE LEVEL                             ;  DEG0L ; 228024  ; 24.228

# Variable resolution parameters (extracted with /usr/local/bin/python ./paramdb2overlap.py)

SURFACE RUNOFF VARIABLE RESOLUTION ; SROVAR ; 8.230
SUB-SURFACE RUNOFF VARIABLE RESOLUTION ; SSROVAR ; 9.230
SNOW EVAPORATION VARIABLE RESOLUTION ; ESVAR ; 44.230
SNOWMELT VARIABLE RESOLUTION ; SMLTVAR ; 45.230
SOLAR DURATION VARIABLE RESOLUTION ; SDURVAR ; 46.230
DOWNWARD UV RADIATION AT THE SURFACE VARIABLE RESOLUTION ; UVBVAR ; 57.230
PHOTOSYNTHETICALLY ACTIVE RADIATION AT THE SURFACE VARIABLE RESOLUTION ; PARVAR ; 58.230
STRATIFORM PRECIPITATION LARGE-SCALE PRECIPITATION VARIABLE RESOLUTION ; LSPVAR ; 142.230
CONVECTIVE PRECIPITATION VARIABLE RESOLUTION ; CPVAR ; 143.230
SNOWFALL CONVECTIVE + STRATIFORM VARIABLE RESOLUTION ; SFVAR ; 144.230
BOUNDARY LAYER DISSIPATION VARIABLE RESOLUTION ; BLDVAR ; 145.230
SURFACE SENSIBLE HEAT FLUX VARIABLE RESOLUTION ; SSHFVAR ; 146.230
SURFACE LATENT HEAT FLUX VARIABLE RESOLUTION ; SLHFVAR ; 147.230
SURFACE SOLAR RADIATION DOWNWARDS VARIABLE RESOLUTION ; SSRDVAR ; 169.230
ALBEDO VARIABLE RESOLUTION ; ALVAR ; 174.230
SURFACE THERMAL RADIATION DOWNWARDS VARIABLE RESOLUTION ; STRDVAR ; 175.230
SURFACE NET SOLAR RADIATION VARIABLE RESOLUTION ; SSRVAR ; 176.230
SURFACE NET THERMAL RADIATION VARIABLE RESOLUTION ; STRVAR ; 177.230
TOP NET SOLAR RADIATION VARIABLE RESOLUTION ; TSRVAR ; 178.230
TOP NET THERMAL RADIATION VARIABLE RESOLUTION ; TTRVAR ; 179.230
EAST-WEST SURFACE STRESS VARIABLE RESOLUTION ; EWSSVAR ; 180.230
NORTH-SOUTH SURFACE STRESS VARIABLE RESOLUTION ; NSSSVAR ; 181.230
EVAPORATION VARIABLE RESOLUTION ; EVAR ; 182.230
SUNSHINE DURATION VARIABLE RESOLUTION ; SUNDVAR ; 189.230
LONGITUDINAL COMPONENT OF GRAVITY WAVE STRESS VARIABLE RESOLUTION ; LGWSVAR ; 195.230
MERIDIONAL COMPONENT OF GRAVITY WAVE STRESS VARIABLE RESOLUTION ; MGWSVAR ; 196.230
GRAVITY WAVE DISSIPATION VARIABLE RESOLUTION ; GWDVAR ; 197.230
SKIN RESERVOIR CONTENT VARIABLE RESOLUTION ; SRCVAR ; 198.230
RUNOFF VARIABLE RESOLUTION ; ROVAR ; 205.230
TOP NET SOLAR RADIATION CLEAR SKY VARIABLE RESOLUTION ; TSRCVAR ; 208.230
TOP NET THERMAL RADIATION CLEAR SKY VARIABLE RESOLUTION ; TTRCVAR ; 209.230
SURFACE NET SOLAR RADIATION CLEAR SKY VARIABLE RESOLUTION ; SSRCVAR ; 210.230
SURFACE NET THERMAL RADIATION CLEAR SKY VARIABLE RESOLUTION ; STRCVAR ; 211.230
TOA INCIDENT SOLAR RADIATION VARIABLE RESOLUTION ; TISRVAR ; 212.230
TOTAL PRECIPITATION VARIABLE RESOLUTION ; TPVAR ; 228.230

# Probability parameters (extracted from METDB with script: ./proba2def.pl on linux)


   10 METRE SPEED PROBABILITY                  ; 10SP  ;  165
   10 METRE WIND GUST OF AT LEAST 10 METRE PER SECOND     ; 10FGG10  ;  100
   10 METRE WIND GUST OF AT LEAST 15 METRE PER SECOND     ; 10FGG15  ;  070
   10 METRE WIND GUST OF AT LEAST 20 METRE PER SECOND     ; 10FGG20  ;  071
   10 METRE WIND GUST OF AT LEAST 25 METRE PER SECOND     ; 10FGG25  ;  072
   10 METRE WIND GUST PROBABILITY              ; 10GP  ;  049
   10 METRE WIND SPEED OF AT LEAST 10 METRE PER SECOND     ; 10SPG10  ;  068
   10 METRE WIND SPEED OF AT LEAST 15 METRE PER SECOND     ; 10SPG15  ;  069
   2 METRE TEMPERATURE LESS THAN 273.15 K      ; 2TL273  ;  073
   2 METRE TEMPERATURE PROBABILITY             ; 2TP  ;  167
   2M TEMPERATURE ANOMALY OF AT LEAST 0K       ; 2TAG0  ;  003
   2M TEMPERATURE ANOMALY OF AT LEAST 1K      ; 2TAG1  ;  002
   2M TEMPERATURE ANOMALY OF AT LEAST 2K      ; 2TAG2  ;  001
   2M TEMPERATURE ANOMALY OF AT MOST -1K       ; 2TALM1  ;  004
   2M TEMPERATURE ANOMALY OF AT MOST -2K       ; 2TALM2  ;  005
   CONVECTIVE AVAILABLE POTENTIAL ENERGY PROBABILITY     ; CAPEP  ;  059
   GEOPOTENTIAL PROBABILITY                    ; ZP  ;  129
   HEIGTH OF 0 DEGREE ISOTHERM PROBABILITY     ; H0DIP  ;  015
   HEIGTH OF SNOWFALL LIMIT PROBABILITY        ; HSLP  ;  016
   MAXIMUM 2 METRE TEMPERATURE PROBABILITY     ; MX2TP  ;  201
   MEAN SEA LEVEL PRESSURE ANOMALY OF AT LEAST 0 PA     ; MSLAG0  ;  010
   MEAN WAVE PERIOD OF AT LEAST 10 S           ; MWPG10  ;  079
   MEAN WAVE PERIOD OF AT LEAST 12 S           ; MWPG12  ;  080
   MEAN WAVE PERIOD OF AT LEAST 15 S           ; MWPG15  ;  081
   MEAN WAVE PERIOD OF AT LEAST 8 S            ; MWPG8  ;  078
   MEAN WAVE PERIOD PROBABILITY                ; MWPP  ;  232
   MINIMUM 2 METRE TEMPERATURE PROBABILITY     ; MN2TP  ;  202
   SHOWALTER INDEX PROBABILITY                 ; SAIP  ;  017
   SIGNIFICANT WAVE HEIGHT OF AT LEAST 2 M     ; SWHG2  ;  074
   SIGNIFICANT WAVE HEIGHT OF AT LEAST 4 M     ; SWHG4  ;  075
   SIGNIFICANT WAVE HEIGHT OF AT LEAST 6 M     ; SWHG6  ;  076
   SIGNIFICANT WAVE HEIGHT OF AT LEAST 8 M     ; SWHG8  ;  077
   SIGNIFICANT WAVE HEIGHT PROBABILITY         ; SWHP  ;  229
   SNOWFALL PROBABILITY                        ; SFP  ;  144
   SURFACE TEMPERATURE ANOMALY OF AT LEAST 0K     ; STAG0  ;  009
   TEMPERATURE ANOMALY GREATER THAN 4 K       ; TAG4K  ;  024
   TEMPERATURE ANOMALY GREATER THAN 8 K       ; TAG8K  ;  025
   TEMPERATURE ANOMALY LESS THAN -2 K          ; TALM2K  ;  020
   TEMPERATURE ANOMALY LESS THAN -4 K          ; TALM4K  ;  023
   TEMPERATURE ANOMALY LESS THAN -8 K          ; TALM8K  ;  022
   TEMPERATURE ANOMALY OF AT LEAST 2 K        ; TAG2K  ;  021
   TEMPERATURE ANOMALY PROBABILITY             ; TAP  ;  130
   TOTAL CLOUD COVER PROBABILITY               ; TCCP  ;  164
   TOTAL PRECIPITATION ANOMALY OF AT LEAST 0 MM     ; TPAG0  ;  008
   TOTAL PRECIPITATION ANOMALY OF AT LEAST 10 MM     ; TPAG10  ;  007
   TOTAL PRECIPITATION ANOMALY OF AT LEAST 20 MM     ; TPAG20  ;  006
   TOTAL PRECIPITATION LESS THAN 0.1 MM        ; TPL01  ;  064
   TOTAL PRECIPITATION OF AT LEAST 1 MM        ; TPG1  ;  060
   TOTAL PRECIPITATION OF AT LEAST 10 MM       ; TPG10  ;  062
   TOTAL PRECIPITATION OF AT LEAST 100 MM      ; TPG100  ;  085
   TOTAL PRECIPITATION OF AT LEAST 150 MM      ; TPG150  ;  086
   TOTAL PRECIPITATION OF AT LEAST 20 MM       ; TPG20  ;  063
   TOTAL PRECIPITATION OF AT LEAST 200 MM      ; TPG200  ;  087
   TOTAL PRECIPITATION OF AT LEAST 25 MM       ; TPG25  ;  098
   TOTAL PRECIPITATION OF AT LEAST 300 MM      ; TPG300  ;  088
   TOTAL PRECIPITATION OF AT LEAST 40 MM       ; TPG40  ;  082
   TOTAL PRECIPITATION OF AT LEAST 5 MM        ; TPG5  ;  061
   TOTAL PRECIPITATION OF AT LEAST 50 MM       ; TPG50  ;  099
   TOTAL PRECIPITATION OF AT LEAST 60 MM       ; TPG60  ;  083
   TOTAL PRECIPITATION OF AT LEAST 80 MM       ; TPG80  ;  084
   TOTAL PRECIPITATION PROBABILITY             ; TPP  ;  228
   TOTAL PRECIPITATION RATE LESS THAN 1 MM PER DAY     ; TPRL1  ;  065
   TOTAL PRECIPITATION RATE OF AT LEAST 3 MM PER DAY     ; TPRG3  ;  066
   TOTAL PRECIPITATION RATE OF AT LEAST 5 MM PER DAY     ; TPRG5  ;  067
   WHITING INDEX PROBABILITY                   ; WHIP  ;  018


# GEMS parameters (to sort when we fully use metdb)

AEROSOL TYPE 1 MIXING RATIO                   ; AERMR01    ;   1.210
AEROSOL TYPE 2 MIXING RATIO                   ; AERMR02    ;   2.210
AEROSOL TYPE 3 MIXING RATIO                   ; AERMR03    ;   3.210
AEROSOL TYPE 4 MIXING RATIO                   ; AERMR04    ;   4.210
AEROSOL TYPE 5 MIXING RATIO                   ; AERMR05    ;   5.210
AEROSOL TYPE 6 MIXING RATIO                   ; AERMR06    ;   6.210
AEROSOL TYPE 7 MIXING RATIO                   ; AERMR07    ;   7.210
AEROSOL TYPE 8 MIXING RATIO                   ; AERMR08    ;   8.210
AEROSOL TYPE 9 MIXING RATIO                   ; AERMR09    ;   9.210
AEROSOL TYPE 10 MIXING RATIO                  ; AERMR10    ;  10.210
AEROSOL TYPE 11 MIXING RATIO                  ; AERMR11    ;  11.210
AEROSOL TYPE 12 MIXING RATIO                  ; AERMR12    ;  12.210
AEROSOL TYPE 1 SOURCE/GAIN ACCUMULATED        ; AERGN01    ;  16.210
AEROSOL TYPE 2 SOURCE/GAIN ACCUMULATED        ; AERGN02    ;  17.210
AEROSOL TYPE 3 SOURCE/GAIN ACCUMULATED        ; AERGN03    ;  18.210
AEROSOL TYPE 4 SOURCE/GAIN ACCUMULATED        ; AERGN04    ;  19.210
AEROSOL TYPE 5 SOURCE/GAIN ACCUMULATED        ; AERGN05    ;  20.210
AEROSOL TYPE 6 SOURCE/GAIN ACCUMULATED        ; AERGN06    ;  21.210
AEROSOL TYPE 7 SOURCE/GAIN ACCUMULATED        ; AERGN07    ;  22.210
AEROSOL TYPE 8 SOURCE/GAIN ACCUMULATED        ; AERGN08    ;  23.210
AEROSOL TYPE 9 SOURCE/GAIN ACCUMULATED        ; AERGN09    ;  24.210
AEROSOL TYPE 10 SOURCE/GAIN ACCUMULATED       ; AERGN10    ;  25.210
AEROSOL TYPE 11 SOURCE/GAIN ACCUMULATED       ; AERGN11    ;  26.210
AEROSOL TYPE 12 SOURCE/GAIN ACCUMULATED       ; AERGN12    ;  27.210
AEROSOL TYPE 1 SINK/LOSS ACCUMULATED          ; AERLS01    ;  31.210
AEROSOL TYPE 2 SINK/LOSS ACCUMULATED          ; AERLS02    ;  32.210
AEROSOL TYPE 3 SINK/LOSS ACCUMULATED          ; AERLS03    ;  33.210
AEROSOL TYPE 4 SINK/LOSS ACCUMULATED          ; AERLS04    ;  34.210
AEROSOL TYPE 5 SINK/LOSS ACCUMULATED          ; AERLS05    ;  35.210
AEROSOL TYPE 6 SINK/LOSS ACCUMULATED          ; AERLS06    ;  36.210
AEROSOL TYPE 7 SINK/LOSS ACCUMULATED          ; AERLS07    ;  37.210
AEROSOL TYPE 8 SINK/LOSS ACCUMULATED          ; AERLS08    ;  38.210
AEROSOL TYPE 9 SINK/LOSS ACCUMULATED          ; AERLS09    ;  39.210
AEROSOL TYPE 10 SINK/LOSS ACCUMULATED         ; AERLS10    ;  40.210
AEROSOL TYPE 11 SINK/LOSS ACCUMULATED         ; AERLS11    ;  41.210
AEROSOL TYPE 12 SINK/LOSS ACCUMULATED         ; AERLS12    ;  42.210
AEROSOL PRECURSOR MIXING RATIO                ; AERPR      ;  46.210
AEROSOL SMALL MODE MIXING RATIO               ; AERSM      ;  47.210
AEROSOL LARGE MODE MIXING RATIO               ; AERLG      ;  48.210
AEROSOL PRECURSOR OPTICAL DEPTH               ; AODPR      ;  49.210
AEROSOL SMALL MODE OPTICAL DEPTH              ; AODSM      ;  50.210
AEROSOL LARGE MODE OPTICAL DEPTH              ; AODLG      ;  51.210
DUST EMISSION POTENTIAL                       ; AERDEP     ;  52.210
LIFTING THRESHOLD SPEED                       ; AERLTS     ;  53.210
SOIL CLAY CONTENT                             ; AERSCC     ;  54.210
CARBON DIOXIDE                                ; CO2        ;  61.210
METHANE                                       ; CH4        ;  62.210
NITROUS OXIDE                                 ; N2O        ;  63.210
TOTAL COLUMN CARBON DIOXIDE                   ; TCCO2      ;  64.210
TOTAL COLUMN METHANE                          ; TCCH4      ;  65.210
TOTAL COLUMN NITROUS OXIDE                    ; TCN2O      ;  66.210
OCEAN FLUX OF CARBON DIOXIDE                  ; CO2OF      ;  67.210
NATURAL BIOSPHERE FLUX OF CARBON DIOXIDE      ; CO2NBF     ;  68.210
ANTHROPROGENIC EMISSIONS OF CARBON DIOXIDE    ; CO2APF     ;  69.210
METHANE SURFACE FLUXES                        ; CH4F       ;  70.210
METHANE LOSS RATE DUE TO RADICAL HYDROXYL     ; kCH4       ;  71.210
WILDFIRE FLUX OF CARBON DIOXIDE               ; CO2FIRE    ;  80.210
WILDFIRE FLUX OF CARBON MONOXIDE              ; COFIRE     ;  81.210
WILDFIRE FLUX OF METHANE                      ; CH4FIRE    ;  82.210
WILDFIRE FLUX OF NON-METHANE HYDRO-CARBONS    ; NMHCFIRE   ;  83.210
WILDFIRE FLUX OF HYDROGEN                     ; H2FIRE     ;  84.210
WILDFIRE FLUX OF NITROGEN OXIDES NOX          ; NOXFIRE    ;  85.210
WILDFIRE FLUX OF NITROUS OXIDE                ; N2OFIRE    ;  86.210
WILDFIRE FLUX OF PARTICULATE MATTER PM2.5     ; PM2P5FIRE  ;  87.210
WILDFIRE FLUX OF TOTAL PARTICULATE MATTER     ; TPMFIRE    ;  88.210
WILDFIRE FLUX OF TOTAL CARBON IN AEROSOLS     ; TCFIRE     ;  89.210
WILDFIRE FLUX OF ORGANIC CARBON               ; OCFIRE     ;  90.210
WILDFIRE FLUX OF BLACK CARBON                 ; BCFIRE     ;  91.210
WILDFIRE OVERALL FLUX OF BURNT CARBON         ; CFIRE      ;  92.210
WILDFIRE FRACTION OF C4 PLANTS                ; C4FFIRE    ;  93.210
WILDFIRE VEGETATION MAP INDEX                 ; VEGFIRE    ;  94.210
WILDFIRE COMBUSTION COMPLETENESS              ; CCFIRE     ;  95.210
WILDFIRE FUEL LOAD CARBON PER UNIT AREA       ; FLFIRE     ;  96.210
WILDFIRE FRACTION OF AREA BURNT               ; BFFIRE     ;  97.210
WILDFIRE OBSERVED AREA                        ; OAFIRE     ;  98.210
WILDFIRE RADIATIVE POWER                      ; FRPFIRE    ;  99.210
WILDFIRE DRY MATTER COMBUSTION RATE DENSITY   ; DMFIRE     ; 100.210
NITROGEN DIOXIDE                              ; NO2        ; 121.210
SULPHUR DIOXIDE                               ; SO2        ; 122.210
CARBON MONOXIDE                               ; CO         ; 123.210
FORMALDEHYDE                                  ; HCHO       ; 124.210
TOTAL COLUMN NITROGEN DIOXIDE                 ; TCNO2      ; 125.210
TOTAL COLUMN SULPHUR DIOXIDE                  ; TCSO2      ; 126.210
TOTAL COLUMN CARBON MONOXIDE                  ; TCCO       ; 127.210
TOTAL COLUMN FORMALDEHYDE                     ; TCHCHO     ; 128.210
NITROGEN OXIDES                               ; NOX        ; 129.210
TOTAL COLUMN NITROGEN OXIDES                  ; TCNOX      ; 130.210
RADON                                         ; RA         ; 181.210
SULPHUR HEXAFLUORIDE                          ; SF6        ; 182.210
TOTAL COLUMN RADON                            ; TCRA       ; 183.210
TOTAL COLUMN SULPHUR HEXAFLUORIDE             ; TCSF6      ; 184.210
ANTHROPOGENIC EMISSIONS OF SULPHUR HEXAFLUORIDE ; SF6APF     ; 185.210
GEMS OZONE                                    ; GO3        ; 203.210
GEMS TOTAL COLUMN OZONE                       ; GTCO3      ; 206.210
TOTAL AEROSOL OPTICAL DEPTH AT 550NM          ; AOD550     ; 207.210
SEA SALT AEROSOL OPTICAL DEPTH AT 550NM       ; SSAOD550 ; 208.210
DUST AEROSOL OPTICAL DEPTH AT 550NM           ; DUAOD550 ; 209.210
ORGANIC MATTER AEROSOL OPTICAL DEPTH AT 550NM ; OMAOD550 ; 210.210
BLACK CARBON AEROSOL OPTICAL DEPTH AT 550NM   ; BCAOD550 ; 211.210
SULPHATE AEROSOL OPTICAL DEPTH AT 550NM       ; SUAOD550 ; 212.210
TOTAL AEROSOL OPTICAL DEPTH AT 469NM          ; AOD469 ; 213.210
TOTAL AEROSOL OPTICAL DEPTH AT 670NM          ; AOD670 ; 214.210
TOTAL AEROSOL OPTICAL DEPTH AT 865NM          ; AOD865 ; 215.210
TOTAL AEROSOL OPTICAL DEPTH AT 1240NM         ; AOD1240 ; 216.210

		*
        /   
    } = Z

    CLASS
    {
        OPERATIONS  ;   OD
        RESEARCH    ;   RD
        REANALYSE   ;   ER
        ECSN        ;   CS
        REANALYSE40 ;   E4
		ERA INTERIM ;   EI
        DEMETER     ;   DM
        PROVOST     ;   PV
        ELDAS       ;   EL
        TOST        ;   TO
        COSMO       ;   CO
        ENSEMBLES   ;   EN
        MERSEA      ;   ME
		SREPS       ;   SR
		DTS         ;   DT
		LACE        ; LAEF   ; ALADIN-LAEF ;   LA
		YOTC        ;   YT
		YOPP        ;   YP
		MACC        ;   MC
		PERMANENT EXPERIMENT ; PE
		E20CM       ; EM
		E20C        ; E2
		ESAT        ; ERA5   ; EA
		CERA20C     ; CERA-20C ; EP

        EURO4M      ; RM
        20CR        ; NCEP 20CR ; NR
		JRA55       ;	J5
		CERASAT     ; CERA-SAT ; ET
		C3S         ; C3
		ERA5L       ; L5
		CEMS        ; CE
        CAMS Research ; CR

		! Member stats

		AUSTRIA		;	AT 
		BELGIUM		;	BE 
		CROATIA		;	HR 
		DENMARK		;	DK 
		FINLAND		;	FI 
		FRANCE		;	FR 
		GERMANY		;	DE 
		GREECE		;	GR 
		HUNGARY		;	HU 
		ICELAND		;	IS 
		IRELAND		;	IE 
		ITALY		;	IT 
		NETHERLANDS	;	NL 
		NORWAY		;	NO 
		PORTUGAL	;	PT 
		SLOVENIA	;	SI 
		SPAIN		;	ES 
		SWEDEN		;	SE 
		SWITZERLAND	;	CH 
		TURKEY		;	TR 
		UNITED KINGDOM  ;	UK
                ! 07/2016 MASV@ECMWF.INT
                ! hack used by UERRA (tigge.def)
                ! class on following line is fictitious 
                UNITED UERRA HACK ;     UZZZ
		! Test
		METAPS      ;   MA
		TEST        ;   TE
    } = OD

    TYPE
    {
		3D VARIATIONAL ANALYSIS     ;   3V
		3D VARIATIONAL GRADIENTS    ;   3G
		4D VARIATIONAL ANALYSIS     ;   4V
		4D VARIATIONAL INCREMENTS   ;   4I
		4D VARIATIONAL GRADIENTS    ;   4G
		ADJOINT SINGULAR VECTOR     ;   AS
		ANALYSIS BIAS               ;	AB
		ANALYSIS INPUT              ;	AI
		ANALYSIS FEEDBACK           ;	AF
		ANALYSIS                    ;   AN
		ASSIMILATION RUN            ;   AR
		BIAS-CORRECTED FORECAST     ;   BF
		CALIBRATION VALIDATION FORECAST      ;   CV
		CLIMATE DISTRIBUTION        ;   CD
		CLIMATOLOGY                 ;   CL
		CLUSTERING INFORMATION      ;   CI
		CLUSTER MEANS               ;   CM
		CLUSTER REPRESENTATIVE      ;   CR
		CLUSTER STD DEVIATIONS      ;   CS
		CONTROL FORECAST            ;   CF
		EMPIRICAL DISTRIBUTION      ;   ED
		ENSEMBLE MEAN               ;   EM
		ENSEMBLE STANDARD DEVIATION ;   ES
		ERRORS IN ANALYSIS          ;   EA
		ERRORS IN FIRST GUESS       ;   EF
		EXTREME FORECAST INDEX      ;   EFI
		EXTREME FORECAST INDEX CONTROL ;   EFIC
		FIRST GUESS                 ;   FG
		FLUX FORCING REALTIME       ;   FF
		FORECAST                    ;   FC
		SIMULATED IMAGES            ;   SIM
		SIMULATED SATELLITE DATA    ;   SSD
		EVENT PROBABILITY           ;   EP
		FORECAST PROBABILITY        ;   FP
		FORECAST ACCUMULATION       ;   FA
		FLUX FORCING                ;   FX
		GRIDDED ANALYSIS INPUT      ;   GAI
		GRIDDED OBSERVATIONS        ;   GO
		GRIDDED SATELLITE DATA      ;   GSD
		GFAS ANALYSIS               ;   GA
		HINDCAST MEAN               ;   HCMEAN
		IMAGES                      ;   IM
		INIT. ANALYSIS              ;   IA
		INITIAL CONDITION PERTURBATION ; ICP
		MODEL ERRORS                ;   ME
        ENSEMBLE MODEL ERRORS       ;   EME
		OBSERVATIONS                ;   OB
		OCEAN FORWARD               ;   OF
		OCEAN REANALYSIS            ;   OR
		OI ANALYSIS                 ;   OI
		OLD FORMAT IMAGES           ;   OLDIM
		PERTURBED ANALYSIS          ;   PA
		PERTURBED FORECAST          ;   PF
		PROBABILITY BOUNDARY        ;   PB
		PROBABILITY DISTRIBUTION    ;   PD
		SCALED ENSEMBLE STANDARD DEVIATION ;   SES
		SENSITIVITY FORECAST        ;   SF
		SENSITIVITY GRADIENT        ;   SG
		SHIFT OF TAILS              ;   SOT
		SIGNAL VARIANCE             ;   SVAR
		SINGULAR VECTOR             ;   SV
		TIME AVERAGE ENSEMBLE MEAN  ;               TAEM
		TIME AVERAGE ENSEMBLE STANDARD DEVIATION ;  TAES
		TRAJECTORY FORECAST         ;   TF
		TUBE                        ;   TU
		WEATHER PARAMETERS          ;   WP
		WEIGHTED ENSEMBLE MEAN               ;   WEM
		WEIGHTED ENSEMBLE STANDARD DEVIATION ;   WES
		FEEDBACK                    ;   FB
                CLIMATE SIMULATION          ;   SI
		CLIMATE 30 DAYS SIMULATION  ;   S3

		FCMEAN
		FCMAX
		FCMIN
		FCSTDEV
		ODB FEEDBACK                ; OFB
		MONDB FEEDBACK              ; MFB
		ODB ANALYSIS INPUT          ; OAI
		SUMMARY FEEDBACK            ; SFB
		FORECAST SENSITIVITY TO OBSERVATIONS IMPACT ; FSOIFB
		FORECAST DEPARTURES FEEDBACK ; FCDFB

        # for EFAS and/or EFCL
        FILL UP                              ; FU
        SIMULATION FORCED WITH OBSERVATIONS    ; SFO

    } = AN
    
    STREAM
    {
		ANALYSIS FOR MULTIANALYSIS PROJECT ; AMAP
        BRACKNELL               ; EXETER  ;   EGRR    
        CHERNOBYL               ;   CH; CHER
        DAILY ARCHIVE           ;   DA; OPER
		DAILY ARCHIVE HINDCASTS ;   DAHC
		DAILY CLIMATOLOGY       ;   DACL
		DAILY CLIMATOLOGY WAVE  ;   DACW
        ENSEMBLE DATA ASSIMILATION      ;   ENDA
		ENSEMBLE DATA ASSIMILATION MONTHLY MEANS                      ; EDMM
		ENSEMBLE DATA ASSIMILATION MONTHLY MEANS OF DAILY MEANS       ; EDMO
		ENSEMBLE WAVE DATA ASSIMILATION MONTHLY MEANS OF DAILY MEANS  ; EWMO
		ENSEMBLE WAVE DATA ASSIMILATION MONTHLY MEANS                 ; EWMM
		ENSEMBLE LONG WINDOW DATA ASSIMILATION      ; ELDA
		ENSEMBLE WAVE LONG WINDOW DATA ASSIMILATION ; EWLA
        ENSEMBLE FORECASTS      ;    EF ; ENFO
		ENSEMBLE FORECAST HINDCASTS ; EFHC
		ENSEMBLE FORECAST HINDCAST STATISTICS ; EFHS
		ENSEMBLE FORECAST OVERLAP ; EFOV
        ENSEMBLE WAVE DATA ASSIMILATION   ;   EWDA
		ENFH
		ENWH
		EFHO
		EWHO
		ERS1                    ;   E1
		EUROSIP MONTHLY MEANS            ;   ESMM
		EUROSIP HINDCAST MONTHLY MEANS   ;   EHMM
        FG                               ;  FGGE         
		GLOBAL FIRE ASSIMILATION SYSTEM  ;   GFAS
		EUROPEAN FLOOD AWARENESS SYSTEM  ;   EFAS
        EUROPEAN FLOOD AWARENESS SYSTEM CLIMATOLOGY ; EFCL
        EUROPEAN FLOOD AWARENESS SYSTEM SEASONAL ; EFSE
        EUROPEAN FLOOD AWARENESS SYSTEM REFORECAST ; EFRF
        EUROPEAN FLOOD AWARENESS SYSTEM SEASONAL REFORECAST ; EFSR
        GLOBAL FLOOD AWARENESS SYSTEM    ;   WFAS
        GLOBAL FLOOD AWARENESS SYSTEM CLIMATOLOGY ; WFCL
        GLOBAL FLOOD AWARENESS SYSTEM SEASONAL ; WFSE
        GLOBAL FLOOD AWARENESS SYSTEM REFORECAST ; WFRF
        GLOBAL FLOOD AWARENESS SYSTEM  SEASONALREFORECAST ; WFSR
        MEANS ARCHIVE           ;   MA
		MELBOURNE               ;   AMMC

		LONG WINDOW DAILY ARCHIVE             ; LWDA
		LONG WINDOW WAVE                      ; LWWV
		MONTHLY FORECAST                      ; MNFC
		MONTHLY FORECAST HINDCASTS            ; MNFH
		MONTHLY FORECAST ANOMALIES            ; MNFA
		MONTHLY FORECAST WAVE                 ; MNFW
		MONTHLY FORECAST HINDCASTS WAVE       ; MFHW
		MONTHLY FORECAST ANOMALIES WAVE       ; MFAW
		MONTHLY FORECAST MEANS                ; MNFM
		MONTHLY FORECAST HINDCASTS MEANS      ; MFHM
		MONTHLY FORECAST ANOMALIES MEANS      ; MFAM
		MONTHLY FORECAST WAVE MEANS           ; MFWM
		MONTHLY FORECAST HINDCASTS WAVE MEANS ; MHWM
		MONTHLY FORECAST ANOMALIES WAVE MEANS ; MAWM 

		MONTHLY STDDEV         ;   SYNOPTIC MONTHLY VARIANCE AND CO-VARIANCE ; MV ; MSDC
		MONTHLY DAILY STDDEV   ;   MONTHLY VARIANCE AND CO-VARIANCE ; MSDA  
		MONTHLY DAILY MEANS    ;   MONTHLY MEANS OF DAILY MEANS ;   MODA
		MONTHLY DAILY FORECAST ACCUMULATION ; MDFA
		MONTHLY MEANS BOERS    ;   MOBR
        MONTHLY                ; SYNOPTIC MONTHLY MEANS ;   MO; MNTH
		MONTHLY STDDEV BOERS   ;   MVBR

		SYNOPTIC MONTHLY VARIANCE AND CO-VARIANCE OF FILTERED FIELDS ;  MFVC
		MONTHLY VARIANCE AND CO-VARIANCE OF FILTERED FIELDS          ;  MFVA

        MONTREAL               ;   CWAO
        MULTIANALYSIS ENSEMBLE DATA  ;   MAED
        MULTIANALYSIS WAVE DATA      ;   MAWV

		MULTIMODEL SEASONAL FORECAST                ; MMSF
		MULTIMODEL SEASONAL FORECAST MEANS          ; MSMM
		MULTIMODEL SEASONAL FORECAST WAVE           ; WAMS
		MULTIMODEL SEASONAL FORECAST WAVE MEANS     ; MSWM
		MULTIMODEL SEASONAL FORECAST MEAN ANOMALIES ; MMSA

		MULTIMODEL MULTIANNUAL FORECAST             ; MMAF
		MULTIMODEL MULTIANNUAL FORECAST MEANS       ; MMAM
		MULTIMODEL MULTIANNUAL FORECAST WAVE        ; MMAW
		MULTIMODEL MULTIANNUAL FORECAST WAVE MEANS  ; MMWM

        OFFENBACH              ;   EDZW
		OCEAN                  ;   OCEA
        OLD MONTHLY FORECAST             ;   MOFC  
        OLD MONTHLY FORECAST MEANS       ;   MOFM  
		OLD WAVE MONTHLY FORECAST        ;   WAMF
		OLD WAVE MONTHLY FORECAST  MEANS ;   WMFM
        PARIS                  ;   LFPW 
		SEASONAL FORECAST      ;   SEAS
		SEASONAL MONTHLY MEANS ; SFMM
		SEASONAL MONTHLY MEANS ANOMALIES ; SMMA
		SEASONAL WAVE MONTLHY MEANS ; SWMM
		SENSITIVE AREA PREDICTIONS ; SEAP
		SENSITIVITY FORECAST   ;    SF ; SENS
		SHORT CUTOFF DAILY ARCHIVE  ;   SCDA
		SHORT CUTOFF WAVE      ;   SCWV
		DELAYED CUTOFF DAILY ARCHIVE  ;   DCDA
		DELAYED CUTOFF WAVE           ;   DCWV
		SSBT                   ;   SSBT
		SSMI                   ;   SSMI
        SUPPLEMENTARY DATA     ;   SD ; SUPD
        ENSEMBLE SUPPLEMENTARY DATA     ;   ESPD
        TOGA                   ;   TG ; TOGA
        TOKYO                  ;   RJTD
        WASHINGTON             ;   KWBC
        WAVE                   ;   WV ; WAVE
        WAVE ENSEMBLE FORECAST ;   WAEF
        WAVE ENSEMBLE FORECAST HINDCASTS ;   EWHC
        WAVE ENSEMBLE FORECAST OVERLAP ;   WEOV
        WAVE ENSEMBLE HINDCAST STATISTICS ;   WEHS
        WAVE HINDCASTS         ;   WVHC
		WAVE MODEL             ;   WAVM
        WAVE SEASONAL FORECAST ;   WASF
        WAVE MONTHLY MEANS     ;   WAMO
		WAVE MONTHLY MEANS OF DAILY MEANS ; WAMD
        WMO                    ;   WM
        UKMO CLIMATE SUPPORT   ;   UKMO
        CNRM CLIMATE SUPPORT   ;   CNRM
        MPI  CLIMATE SUPPORT   ;   MPIC
		2243
		2242
    } = DA

	ORIGIN 
	{
		OFF ; OFF
        WASHINGTON            ;   7     ; KWBC
        BRACKNELL   ; EXETER  ;   74    ; EGRR    
        FLEET NUMERICAL       ;   58    ; FNMOC ; FNMO
        OFFENBACH             ;   78    ; DWD   ; EDZW
        ECMWF                 ;   98    ; ECMF
		TOULOUSE              ;   85    ; LFPW
		PARIS                 ;   84    ; LFPW
		MADRID                ;   214   ; LEMM
		UNIVERSITY OF VIENNA  ;   244   ; VUWIEN
		KNMI                  ;   245   ; KNMI
		INGV                  ;   235   ; INGV
		CERFACS               ;   239   ; CRFC
		IFMK                  ;   246   ; IFMK
		HADLEY CENTRE         ;   247   ; HADC
		CONSENSUS             ;   255   ; CONSENSUS
# for TIGGE
		MELBOURNE             ;   1     ; AMMC
        TOKYO                 ;   34    ; RJTD
        MONTREAL              ;   54    ; CWAO
        BEIJING               ;   38    ; BABJ
		SEOUL                 ;   40    ; RKSL
		CPTEC                 ;   46    ; SBSJ
		CNMC                  ;   80    ; CNMC
		OSLO                  ;   88    ; ENMI

# for C3S
		CMCC                  ;   CMCC

# for EFAS
        COSMO                 ;   COSMO

# COMMON
		/
		ALL
	} = OFF

    MODEL
	{
		OFF
		ECMF
		EDZW
		EGRR
		LFPW
		KWBC
		NONE
		HRM
		LM
		IFS
		GLOBAL ; GLOB
		@
	} = OFF

	SYSTEM {
		*
		ALL
	}

	METHOD {
		TO ;    TO
		BY ;    BY 
        ALL ;   ALL
        OFF ;   OFF
        *   
        /   
	}

	PRODUCT {
		INSTANTANEOUS     ; INST
		TIME-SERIES       ; TIMS
		TIME-AVERAGE      ; TAVG
		TIME-ACCUMULATION ; TACC
		ALL
	} = INSTANTANEOUS

	SECTION {
		HORIZONTAL  ; H
		VERTICAL    ; V
		ZONAL       ; Z 
		MERIDIONAL  ; M
		ALL
	} = HORIZONTAL



    LEVTYPE  
    {
		POTENTIAL VORTICITY   ; PV
		POTENTIAL TEMPERATURE ; PT
        SURFACE               ; SFC
        PRESSURE LEVELS       ; PL
        MODEL LEVELS          ; ML
		DEPTH                 ; DP
		OCEAN WAVE            ; WV
		LAYER                 ; LAYER
		CATEGORY              ; CAT
        OCEAN 2D FIELD        ; O2D
        OCEAN 3D FIELD        ; O3D
        SOIL LEVELS           ; SOL
		OFF
		ALL
    } = PL
    
    REPRES 
    {
        BUFR            ;   BU
        SPHERICAL HARMONICS ;   SH
        LAT LONG GRID       ;   LL
        GAUSSIAN GRID       ;   GG
		SPACE VIEW          ; SV
		OCEAN GRID          ; OG
		ALL
    } = SH

    OBSTYPE
    {
		 *   
		 /   

		 ALL                = (NSD/SD)
		 CONVENTIONAL; NSD  = (LSD/SSD/VSNS/SLNS/SLS/OD/DD/CC/SF/GBGPS/OSTIA)
		 SD                 = (SDS/VSS/SSMI/SSMIS/SSBT/TRMM/QSCAT/REO3/IASI/ATMS/CRIS/VASS)

# Image stuff

GRIB IMAGES #= (0/1/10/20)

	FIRST INFRARED BAND  ; FIB ; 0
	SECOND INFRARED BAND ; SIB ; 1
	FIRST VISIBLE BAND   ; FVB ; 10
	WATER VAPOR BAND     ; WVB ; 20

# Extractions

BUFR = (1/3/9/11/13/19/21/22/23/28/61/62/63/82/83/84/85/86/87/91/92/95/96/101/102/103/106/110/109/111/112/113/140/142/144/145/146/147/149/164/170/172/176/178/180/230/231)
WAVESCAT = (121)
SCAT = (122)
RALT = (123)
TOVH = (53)
GRAD = (88/89/189/190)
ATOV = (55)
AIRS = (57)
STORM = (31)
IMSSNOW = (165)
AMSU_EARS = (155)
BALTIC_CI = (237)
WAVESAR = (210)
IASI = (240)
OSTIA = (26)
ENVISAT_MERIS = (212)
ATMS = (201)
CRIS = (202)
SMOS = (203)
AMSR2_GC = (60)
DMBO = (181/182)
SAPHIR = (211)
MWRIBT = (153)
AEOLUS = (251)

# FeedBack

FBCONV = (1/3/9/11/13/19/21/22/23/28/65/82/83/86/87/91/92/95/96/101/102/103/106/110/140/142/143/144/145/164)
FBSCAT = (122/136/137/139)
FBSSMI = (127)
FBTMI  = (129)
FBTOVS = (53)
FBRAD1C = (54/55)
FBGEOS = (89/189/190)
FBTRMR = (255)
FBREO3 = (206)
FBAIRS = (57)
FBAMSRE = (59)
FBSSMIS = (49)
FBGPSRO = (250)
FBIASI = (240)
FBWINDSAT = (156)

# Type LSD (NSD)

	LAND SURFACE DATA         ; LSD = (1/2/3/4/7/28/140/147/165/170/172/176/178)

	SYNOP LAND                ; S   ; 1
	SYNOP RECORD 2 LAND       ; S2  ; 2
	SYNOP AUTO LAND           ; SA  ; 3
	SYNOP AUTO RECORD 2 LAND  ; SA2 ; 4
	SOIL AND EARTH TEMPERATURE; SET ; 7
	METAR                     ; METAR ; 140
	AUTO METAR                ; AMETAR ; 147
	SNOW COVER                ; SNOWCOVER ; SNOW ; 165
	SNOW DEPTH                ; SNOWD ; 28
	BUFR LAND SYNOP               ; BS   ; 170
	BUFR LAND SYNOP 2             ; BS2  ; 172
	BUFR LAND SYNOP WMO Region 6  ; BSR6 ; 176
	BUFR LAND SYNOP 1 HOURLY      ; BS1H ; 178


# Type SSD (NSD)

	SEA SURFACE DATA ; SSD  = ( 9/11/12/13/14/19/21/22/23/180/181/182 )

	SYNOP ABBREVIATED SHIP    ; SAB ; 9
	SYNOP SHIP               ; SS   ; 11
	SYNOP RECORD 2 SHIP      ; SS2  ; 12
	SYNOP AUTO SHIP          ; SAS  ; 13
	SYNOP AUTO RECORD 2 SHIP ; SAS2 ; 14
	SHRED                    ; SH   ; 19
	DRIBU SURFACE             ; DSU ; 21
	BATHY SURFACE             ; BSU ; 22
	TESAC SURFACE             ; TSU ; 23
	OSTIA                     ;       26
	BUOY                      ;       27
	BUFR SHIP SYNOP           ; BSS ; 180
	BUFR MOORED BUOYS         ; BMB ; 181
	BUFR DRIFTING BUOYS       ; BDB ; 182


# Type VSNS (NSD)

VERTICAL SOUNDINGS NOT SATELLITE ; VSNS = (91/92/95/96/97/101/102/103/104/105/106/107/109/111/112/113/230/231)

	PILOT LAND   ;  P   ; 91
	PILOT SHIP   ;  PS  ; 92
	WIND PROFILE ;  WP  ; 95
	EUROPEAN WIND PROFILE;  EWP  ; 96
	EUROPEAN WIND AND TEMPERATURE PROFILE;  EWTP  ; 97
	TEMP LAND    ;  T   ; 101
	TEMP SHIP    ;  TS  ; 102
	TEMP DROP    ;  TD  ; 103
	ROCOB LAND   ;  R   ; 104
	ROCOB SHIP   ;  RS  ; 105
	TEMP MOBILE	 ;  TM  ; 106
	CLIMATE TEMP ;  CT  ; 107
	HIGH RESOLUTION TEMP LAND ; HRT ; 109
	HIGH RESOLUTION TEMP SHIP ; HRTS ; 111
	BUFR LAND PILOT ; BP  ; 112
	BUFR SHIP PILOT ; BPS ; 113
	BUFR TEMP DROP     ; BTD  ; 230
	BUFR TEMP DESCENT  ; BTDC ; 231

# Type VSS (SD)

VERTICAL SOUNDINGS SATELLITE ; VSS = (51/53/54/55/56/57/59/61/62/63/65/71/72/73/75/138/139/153/155/211/250)

	HIGH RESOLUTION        ;  HR    ; 51
	RTOVS                  ;  RTOV  ; 53
	TOVS1b                 ;  TOVB  ; 54
	ATOVS                  ;  ATOV  ; 55
	ATOVS PRODUCTS         ;  ATOP  ; 56
	AIRS                   ;  AIRS  ; 57
	ADVANCED MICROWAVE SCANNING RADIOMETER  ;  AMSRE ; 59
	ADVANCED MICROWAVE SCANNING RADIOMETER 2 ;  AMSR2 ; 60
	SATEM MEAN TEMPERATURE ;  SMT   ; 61
	SATEM WATER            ;  SW    ; 62
	SATEM HIGHER LEVEL     ;  SHL   ; 63
	SATEM LEVELS MERGED    ;  SLM   ; 65
	MEAN TEMPERATURE       ;  MT    ; 71
	WATER                  ;  W     ; 72
	HIGHER LEVEL           ;  HL    ; 73
	TOVS LEVELS MERGED     ;  TLM   ; 75
	ATOVS EUMETSAT         ;  ATEU  ; 155
	GPS RADIO OCCULTATION  ; GPSRO ; 250
	ASCAT                  ; 139
	OSCAT                  ; 138
	SAPHIR                 ; 211 
	MICRO WAVE RADIATION IMAGER   ; MWRIBT  ; 153 

	IASI_SCREENED          ; IASI  ; 240

CHEMICAL CONSTITUENT; CC = (162/159)

#	SURFACE OZONE           ;  SO    ; 157
#	SURFACE OZONE AVERAGED  ;  SOA   ; 158
	OZONE PARTIAL           ;  OP    ; 159
	OZONE VERTICAL SOUNDING ;  OVS   ; 162

# Synoptic Features

SYNOPTIC FEATURES; SF = (31)
    STORM ; STOR ; 31
	TROPICAL CYCLONE ; TC ; 32

SATELLITE = (VSS/SSBT/SSMI/SSMIS/QSCAT/REO3/WSAT/VASS/ATMS)

# Type SLNS (NSD)

SINGLE LEVEL UPPER AIR NOT SATELLITE ; SLNS = (141/142/143/144/145/146/149)

	CODAR ;  COD ; 141
	AIREP ;  AIR ; 142
	COLBA ;  COL ; 143
	AMDAR ;  AM  ; 144
	ACARS ;  AC  ; 145
	E-AMDAR ;  EAM  ; 146
	ACARS with mixing ratio ;  ACMR ; 149

# Type SLS (NSD)

SINGLE LEVEL UPPER AIR SATELLITE ; SLS = (82/83/84/85/86/87/88/89/189/190)

	SATOB SECTION 2                            ; SAT2 ; 82
	SATOB SECTION 3                            ; SAT3 ; 83
	SATOB SECTION 4                            ; SAT4 ; 84
	SATOB SECTION 5                            ; SAT5 ; 85
    HIGH RESOLUTION WINDS                      ; SAT6 ; 86 
    HIGH DENSITY UNIFIED FORMAT SATELLITE WINDS; SAT7 ; 87
	GEOSTATIONARY RADIANCES                    ; GEOR ; 88 
	GEOSTATIONARY CLEAR SKY RADIANCES          ; GCSR ; 89
	GEOSTATIONARY MSG RADIANCES                ; GMSGR ; 189
	GEOSTATIONARY ALL SKY RADIANCES            ; GASR ; 190

# Type OD (NSD)

OCEANOGRAPHIC DATA      ;   OD = (131/132/133/184) 

	DRIBU OCEANOGRAPHIC     ;   DO ; 131
	BATHY OCEANOGRAPHIC     ;   BO ; 132
	TESAC OCEANOGRAPHIC     ;   TO ; 133
	BUFR ARGO               ;   ARGO ; 184

# Type DD (NSD)

DERIVED DATA ;   DD = (164/237) 
	PAOBS ; PA ; 164
	BALTIC SEA ICE ; BICE ; 237



# Type SDS, ERS1 (SD)

SURFACE DATA SATELLITE  ; ERS1; SDS = (121/122/123/124/210/212/213/214/216/217/218)

	WAVE SCATTEROMETER      ; WAS  ; 121
	WIND SCATTEROMETER      ; WIS  ; 122
	RADAR ALTIMETER         ; RAL  ; 123
	SEA SURFACE TEMPERATURE ; SST  ; 124
	ENVISAT SAR             ; ESAR  ; 210
	ENVISAT MERIS           ; EMERIS ; 212
	ENVISAT RADAR ALTIMETER ; ERA  ; 213
	JASON RADAR ALTIMETER ;   JRA  ; 214
	JASON2 RADAR ALTIMETER ;  J2RA ; 216
	CRYOSAT-2 RADAR ALTIMETER ;  CRYORA ; 217
	SARAL RADAR ALTIMETER ;  SARAL ; 218

# RADAR
	REPROCESSED WIND        ; RW ;  NEXRAD ; 125
NEXRAD_RR = (125)

# SSMI
	
	MICROWAVE IMAGES  ;  SSMI = (126)
        SPECIAL SENSOR MICROWAVE IMAGER SOUNDER ; SSMIS = (49)

SEA SURFACE BRIGTHNESS TEMPERATURE ; SSBT ; 127

# TRMM
TRMM = (129/130)
TMI BRIGHTNESS TEMPERATURES              ; TBT  ; 129
TMI INSTANTANEOUS 3-D RAINFALL STRUCTURE ; TI3R ; 130

# GPM
GPM = (224)
GMI BRIGHTNESS TEMPERATURES              ; GBT  ; 224



QSCAT = (137/138)
QUIKSCAT                                 ; QSCA ; 137
QUIKSCAT SEAWINDS                        ; QSSW ; 138

REO3 = (206/207/208/209)
RETRIEVED OZONE                          ; REO3 ; 206
MODIS AEROSOL                                                            ; MODIS     ; 207
LAYER INTEGRATED MASS DENSITY                                            ; LIMD      ; 208
LAYER INTEGRATED MASS DENSITY WITH AVERAGING KERNELS                     ; LIMD_AK   ; 209

GBGPS = (110)
GROUND BASED GPS                         ; PGPS ; 110

WINDSAT                                  ; WSAT ; 156
VASS = (154)
VERTICAL ATMOSPHERIC SOUNDER SYSTEM      ; VASS ; 154

ADVANCED TECHNOLOGY MICROWAVE SOUNDER      ; ATMS ; 201
CROSS-TRACK INFRARED SOUNDER               ; CRIS ; 202

} = SYNOP LAND

	REPORTYPE {

%include "reportypes.def"

		*
		/
		OFF
	} = OFF

	OBSGROUP {	
#		CONVENTIONAL
		SAT          ; SATELLITE
		ERS1 
		TRMM
		QSCAT
#		IASI

		# reo3 needs to stay for compatibility 
		REO3

%include "obsgroups.def"

	} = CONV
    
    DOMAIN
    {
		GENERAL EUROPEAN AREA   ; G
		GLOBE                   ; G
        MEDITERRANEAN           ; M
        NORTHERN HEMISPHERE     ; N
        SOUTHERN HEMISPHERE     ; S
		BALTIC AND BLACK SEA    ; B
		EUROPE                  ; E
        NORTH WEST EUROPE       ; A
        NORTH EAST EUROPE       ; B
        SOUTH WEST EUROPE       ; C
        SOUTH EAST EUROPE       ; D
		WESTERN ATLANTIC        ; W
		FASTEX                  ; F
		TROPICS                 ; T
		TROPICS 2               ; U
		X
		ALL
		V
		H
		I
		J
		K
		L
		O
		P
		Q
		R
		Y
		Z
    } = GLOBE

    DATE
    {
        JANUARY     ;   JAN
        FEBRUARY    ;   FEB
        MARCH       ;   MAR
        APRIL       ;   APR
        MAY         ;   MAY
        JUNE        ;   JUN
        JULY        ;   JUL
        AUGUST      ;   AUG
        SEPTEMBER   ;   SEP
        OCTOBER     ;   OCT
        NOVEMBER    ;   NOV
        DECEMBER    ;   DEC
        *   
        CURRENT DATE ; 0
        YESTERDAY    ; -1
		TO          ; TO
		BY          ;   BY
		/
		OFF
    } = CURRENT DATE

	IDENT {
        METEOSAT 3 ; MS3  ; 50
        METEOSAT 4 ; MS4  ; 51
        METEOSAT 5 ; MS5  ; 52
        METEOSAT 6 ; MS6  ; 53
        METEOSAT 7 ; MS7  ; 54
        METEOSAT 8 ; MS8  ; 55
		METEOSAT 9  ; MS9  ; 56
		METEOSAT 10 ; MS10 ; 57
        GOES 8     ; GOES ; 252
        GOES 9     ;        253
        GOES 10    ;        254
        GOES 11    ;        255
        GOES 12    ;        256
		GOES 13    ;        257
		GOES 14    ;        258
		GOES 15    ;        259
		DMSP 10    ; 204
		DMSP 13    ; 246
		TERRA      ; 783
		AQUA       ; 784
		/
		OFF
	} = OFF

	INSTRUMENT {
		MHS          ; 203
		MVIRI        ; 205
		SEVIRI       ; 207
		GOES IMAGER  ; 615
		AMSU-A       ; 570
		AMSU-B       ; 574
		MSU          ; 623
		HIRS2        ; 605
		HIRS3        ; 606
		SSU          ; 627
		MODIS        ; 389
		*
		OFF
		/
	} = OFF

	CHANNEL {
		*
		OFF; OFF
		/
		TO 
		ALL
	} = OFF

	GRID {
		N32
		N48
        N64
		N80
        N96
		N128
		N160
		N200
		N256
		N320
		N400
		N512
		N640
        N1024
		N1280
		F32
		F48
        F64
		F80
        F96
		F128
		F160
		F200
		F256
		F320
		F400
		F512
		F640
        F1024
		F1280
		O32
		O48
        O64
		O80
        O96
		O128
		O160
        O192
		O200
		O256
		O320
		O400
		O512
		O640
		O800
        O912
		O1024
		O1280
		O2000
        O8000
		*
		/
        OFF     ;  OFF
	} = OFF

    PADDING  
    {
		AUTOMATIC   ; AUTO
		NONE        ; N    ; 0
		OFF
		*
    } = OFF
    
	BRANCH 
	{
		TRUE
		FALSE
		OFF
	} = OFF

	LSM
	{
		ON
		OFF
	} = OFF

	PPENGINE 
	{
		EMOS
		MIR
		OFF
	} = OFF

	TRUNCATION
	{
		NONE
		AUTO
		*
		OFF
	} = OFF

	INTGRID
	{
		NONE
		SOURCE
		AUTO
		&_DUMMY&GRID
	} = OFF

} ! END OF DUMMY

HELP    ;   Displays prints help file   ;   INTERNAL
{
}

!------------------------------------------------------------------------

NEWS    ;   Displays prints news file   ;   INTERNAL
{
}

!------------------------------------------------------------------------

END ;   Normal exit from mars system    ;   INTERNAL
{
}

!------------------------------------------------------------------------

DEFAULT ;   Reset defaults    ;   INTERNAL
{
}

!------------------------------------------------------------------------

ARCHIVE ;   Archives data   ;   MARS
{

	DATASET [ priority = 0 ]
	{
		@
	}

    CLASS  { &_DUMMY&CLASS  } = OD

    TYPE   { &_DUMMY&TYPE   } = AN

    STREAM { &_DUMMY&STREAM } = DA
    
	MODEL  { &_DUMMY&MODEL  } = OFF

	ORIGIN { &_DUMMY&ORIGIN } = OFF

	SYSTEM { &_DUMMY&SYSTEM 
			  OFF } = OFF
	METHOD { &_DUMMY&METHOD 
			  OFF } = OFF

    REPORTYPE { &_DUMMY&REPORTYPE } = OFF

	PRODUCT { &_DUMMY&PRODUCT 
			  OFF } = OFF
	SECTION { &_DUMMY&SECTION 
			  OFF } = OFF
	LATITUDE { @ 
			   OFF } = OFF
	LONGITUDE { @ 
				OFF } = OFF

    EXPVER  [ priority = 1 ]
    {
		@
        "       
        *       
        /
    } = 1
    
    LEVTYPE { &_DUMMY&LEVTYPE } = PL 
    
    LEVELIST  
    {
		TO ; TO
		BY ; BY 
        OFF ;   OFF
        *       
        /       
    } = 1000/850/700/500/400/300
    
    REPRES { &_DUMMY&REPRES } = SH
    
    DOMAIN 
    {
	&_DUMMY&DOMAIN
    } = G
    
    OBSTYPE { ALL
		 KNOWN				= (ALL)
	&_DUMMY&OBSTYPE } = S

    IDENT
    {
		&_DUMMY&IDENT
		ALL 
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF

	OBSGROUP { ALL
	&_DUMMY&OBSGROUP } = CONVENTIONAL	
    
    PARAM { &_DUMMY&PARAM } = Z

    CHANNEL { &_DUMMY&CHANNEL } = OFF
    
	INSTRUMENT { &_DUMMY&INSTRUMENT } = OFF

    DATE 
	{
		&_DUMMY&DATE
    } = CURRENT DATE
    
    VERIFY 
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE 
	{
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    FCMONTH 
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY    !                               6
    } = 12
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	RANGE 
	{
		*
		OFF; OFF
	} = OFF

    REFERENCE 
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY        
		OFF
    } = OFF 

    STEP
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
    } = 00
    
    ANOFFSET
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    }
    
    ENSEMBLE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    CLUSTER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    
    PROBABILITY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    FREQUENCY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  
        *   
        /
    } = OFF
    
    DIRECTION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  
        *   
        /
    } = OFF
    
    SOURCE
    {
		@
		/
        "   
    } = ""
    
    LOGSTATS
    {
		@
        "   
		OFF
    }

    DISP
    {
        NEW ;   N
        OLD ;   OLD
		REMOVE
		FAIL
    } = NEW
    
	STYLE
    {
        DISSEMINATION  
        OFF   
    } = OFF

	INTERPOLATION
    {
        NN   ; NEAREST NEIGHBOUR  
        NLSM ; NEAREST LSM  
		BILINEAR
		LINEAR
		LFIT ; LINEAR FIT
		CUBIC
		AVERAGE WEIGHTED
		AVERAGE
        OFF   
    } = OFF

    AREA
    {
        GLOBE   ;   G
        EUROPE  ;   E
    } = G
    
    RESOL
    {
        /
        *   
    }

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF; OFF
		@
		"
	} = OFF

    GRID
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
    PASSWORD
    {
        "   
    } = ""

	OPTIMISE 
    {
		ON
		OFF
	} = OFF

	DATABASE [ priority = 1 ]
	{
		@
		/
		OFF
	} 

	EXPECT [ priority = 0 ]
	{
		ANY
		*
		OFF ; OFF
	} = OFF

	JOB
	{
		"
		OFF
	} = OFF

    USE  
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		OFF; OFF
    } = OFF

	CRC
	{
		ON
		OFF
	} = OFF

    DUPLICATES  
    {
        KEEP
        REMOVE
    } = REMOVE

	PADDING
	{
		&_DUMMY&PADDING
	} = OFF

    PROCESS  
    {
		LOCAL ; LOCAL
		SERVER 
        OFF ;   OFF
    } = OFF

	BRANCH { &_DUMMY&BRANCH } = OFF

} ! END OF ARCHIVE

!------------------------------------------------------------------------

LIST    ;   LIST FDF ENTRIES AND CFS FILES  ;   MARS
{
    
	DATASET [ priority = 0 ]
	{
		@
	}

    CLASS  
	{ 
		&_DUMMY&CLASS  
		/ 
		ALL
	} 
    
    TYPE   
	{ 
		&_DUMMY&TYPE  
		/  
		ALL
	} 

    STREAM 
	{ 
		&_DUMMY&STREAM 
		/ 
		ALL
	} 
    
	MODEL 
	{
		&_DUMMY&MODEL
		/
		ALL
	}

	ORIGIN 
	{
		&_DUMMY&ORIGIN
		/
		ALL
	}

	SYSTEM 
	{ 	
		&_DUMMY&SYSTEM 
		/
		ALL 
	} 

	METHOD 
	{ 	
		&_DUMMY&METHOD 
		/
		ALL 
	} 

	PRODUCT 
	{ 	
		&_DUMMY&PRODUCT 
		/
		ALL 
	} 

	SECTION 
	{ 	
		&_DUMMY&SECTION 
		/
		ALL 
	} 

	LATITUDE 
	{ 	
		@
		/
		ALL 
	} 

	LONGITUDE 
	{ 	
		@
		/
		ALL 
	} 

    EXPVER{
		@
		/
		ALL
    } 
    
    LEVTYPE 
	{ 
		&_DUMMY&LEVTYPE 
		/ 
		ALL
	}
    
    LEVELIST
    {
		TO ; TO
		BY ; BY 
        ALL ;   ALL
        OFF ; OFF;   OFF
        *   
        /   
    }
    
    REPRES { 
		&_DUMMY&REPRES 
		/ 
		ALL
	}
    
    DOMAIN  
    {
		&_DUMMY&DOMAIN
		/
		ALL
    } 

    OBSTYPE 
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
		/
    } 

	OBSGROUP { ALL
	&_DUMMY&OBSGROUP } = ALL
    
    REPORTYPE { ALL
	&_DUMMY&REPORTYPE } = OFF

    DUPLICATES  {
        KEEP
        REMOVE
    } = KEEP
    
    PARAM 
    {
        ALL             ;   ALL
        &_DUMMY&PARAM
		/
    }
    
    CHANNEL 
	{ 	
		ALL             ; ALL
		&_DUMMY&CHANNEL 
	} 

    INSTRUMENT 
	{ 	
		ALL             ; ALL
		&_DUMMY&INSTRUMENT 
	} 

	IDENT
	{
		ALL
		&_DUMMY&IDENT
		*
	}

	PSEUDODATE
	{
		LATEST
		EARLIEST
	}

    DATE
    {
		&_DUMMY&DATE
		ALL
    } 
    
    VERIFY 
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE 
	{
		&_DUMMY&DATE
		ALL
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    FCMONTH 
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
	MONTH
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

	YEAR
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}
    
	DECADE
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY           !        6
		ALL ;   ALL
    }
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

    REFERENCE 
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    } = OFF 

    STEP
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    }
    
    ANOFFSET
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    }

    ENSEMBLE
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } 
    
    CLUSTER
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } 
    
    
    PROBABILITY
    {
        ALL ;   ALL
		TO  ; TO
        OFF ;   OFF
        *   
        /
    }

    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } 

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    }

    FREQUENCY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
	SHOW
	{
		@
		/
	}

	HIDE
	{
		@
		/
	}

 
    TARGET
    {
		@
        "   
		OFF
    }

	DATABASE [ priority = 1 ]
	{
		@
		/
		OFF
	} 

	RANGE 
	{
		*
		OFF; OFF
	} = OFF


    SOURCE
    {
		@
        "   
    } = ""

    FIELDSET  
    {
        @
    }
    
    CFSPATH  
    {
        "   
    } = ""
    
    FORMAT  
    {
        PACKED      ;   P
        UNPACKED    ;   U
        GRIB EDITION 1 ;   GRIB1
        GRIB EDITION 2 ;   GRIB2
		NETCDF
		ODB
		ASCII
		OFF         ;   OFF
    } = OFF
    
    RESOL 
    {
        ARCHIVED VALUE       ;   AV
		AUTOMATIC RESOLUTION ;   AUTO
		OFF                  ;   OFF
		319
		213
		106
		63
        *   
    } = OFF
    
    ACCURACY 
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = OFF
    
    AREA  
    {
        GLOBE               ;  GLOBE;  G
        EUROPE              ;  EUROPE; E
        *   
        /   
		OFF; OFF
    } = OFF

	LOCATION 
	{
		*
        /   
        OFF     ;  OFF
	} = OFF

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    BLOCK  
    {
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF

    GRID  
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
	PPENGINE   { &_DUMMY&PPENGINE   } = OFF

	GAUSSIAN 
	{
		REDUCED
		REGULAR
		OFF     ; OFF;  OFF
	} = OFF

	SPECIFICATION 
	{
		*
		OFF
	} = OFF

    LAUNCH  
    {
        "   
    } = ""
    
	PADDING
	{
		&_DUMMY&PADDING
	} = OFF

	JOB
	{
		"
		OFF
	} = OFF

    USE  
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
		OFF; OFF
    } = OFF
    
    PASSWORD  
    {
        "   
        OFF ;   OFF
    } = OFF
    
    COSTONLY  
    {
        YES ;   Y
        NO  ;   N
		OFF ;   OFF
    } = OFF
    
    PROCESS  
    {
		LOCAL ; LOCAL
		SERVER
        OFF ;   OFF
    } = OFF

	BRANCH { &_DUMMY&BRANCH } = OFF

	EXPECT 
	{
		*
		OFF ; OFF
		ANY
	} = OFF

	OUTPUT {
		TABLE
		BROWSE
		COST
		SEARCH
		TREE
                JSON
	} = TABLE


} ! END OF LIST

STAGE    ;   STAGE FIELDS ;    MARS
{
    
	DATASET [ priority = 0 ]
	{
		@
	}

    CLASS
	{ 
		&_DUMMY&CLASS  
	} = OD
    

    TYPE
	{ 
		&_DUMMY&TYPE   
		ALL
	} = AN

    STREAM
	{ 
		&_DUMMY&STREAM 
	} = DA
    
	MODEL 
	{
		&_DUMMY&MODEL
		/
	} = OFF

	ORIGIN 
	{
		&_DUMMY&ORIGIN
		/
	} = OFF

    EXPVER
	{
		@
        *   
    } = 1
    

	SYSTEM 
	{ 	
		&_DUMMY&SYSTEM 
		/
		ALL 
	} 

	METHOD 
	{ 	
		&_DUMMY&METHOD 
		/
		ALL 
	} 

	PRODUCT { &_DUMMY&PRODUCT 
			  OFF } = OFF
	SECTION { &_DUMMY&SECTION 
			  OFF } = OFF
	LATITUDE { @ 
			   OFF } = OFF
	LONGITUDE { @ 
				OFF } = OFF

    LEVTYPE
	{ 
		&_DUMMY&LEVTYPE 
	} = PL 
    
    LEVELIST
    {
		TO ; TO
		BY ; BY 
        ALL ;   ALL
        OFF ; OFF;   OFF
        *   
        /   
    } = 1000/850/700/500/400/300
    
    REPRES
	{ 
		&_DUMMY&REPRES 
	} = SH
    
    DOMAIN
    {
		&_DUMMY&DOMAIN
    } = G

    OBSTYPE
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
    } = S

	OBSGROUP 
	{ 
		&_DUMMY&OBSGROUP
		OFF    ; OFF
	} = OFF

    REPORTYPE { &_DUMMY&REPORTYPE } = OFF


    PARAM
    {
        ALL             ;   ALL
        &_DUMMY&PARAM
    } = Z
    
    CHANNEL { 
		ALL     ; ALL
		&_DUMMY&CHANNEL 
	} = OFF

    INSTRUMENT { 
		ALL     ; ALL
		&_DUMMY&INSTRUMENT 
	} = OFF

    DATE
    {
		&_DUMMY&DATE
    } = CURRENT DATE
    
    VERIFY 
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE 
	{
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    FCMONTH 
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
    TIME 
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY           !        6
		ALL ;   ALL
    } = 12

	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	RANGE 
	{
		*
		OFF; OFF
	} = OFF
    
	REFERENCE 
	{
		ALL ;   ALL
		*
		/
		TO  ;   TO
		BY  ;   BY
		OFF
	} = OFF

    STEP
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    } = 00
    
    ANOFFSET
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    }

    ENSEMBLE
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } = OFF
    
    CLUSTER
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } = OFF
    
    
    PROBABILITY
    {
        ALL ;   ALL
		TO  ; TO
        OFF ;   OFF
        *   
        /
    } = OFF

    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    FREQUENCY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    BLOCK
    {
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF

    IDENT
    {
		ALL 
		&_DUMMY&IDENT 
    }=OFF
    
	TARGET 
	{
		@
		"
		OFF
	} = ""

    FIELDSET  
    {
        @
    }
    
	RESOL
	{
        ARCHIVED VALUE       ;   AV
		AUTOMATIC RESOLUTION ;   AUTO
		OFF                  ;   OFF
		319
		213
		106
        *   
	} = AUTO

	ACCURACY
	{
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
	} = N

	STYLE
    {
        DISSEMINATION  
        OFF   
    } = OFF

	AREA
	{
        GLOBE               ;  GLOBE;  G
        EUROPE              ;  EUROPE; E
        NORTHERN HEMISPHERE OCTANT 1    ;   N1
        NORTHERN HEMISPHERE OCTANT 2    ;   N2
        NORTHERN HEMISPHERE OCTANT 3    ;   N3
        NORTHERN HEMISPHERE OCTANT 4    ;   N4
        SOUTHERN HEMISPHERE OCTANT 1    ;   S1
        SOUTHERN HEMISPHERE OCTANT 2    ;   S2
        SOUTHERN HEMISPHERE OCTANT 3    ;   S3
        SOUTHERN HEMISPHERE OCTANT 4    ;   S4
        *   
        /   
	} = G

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF; OFF
		@
		"
	} = OFF

	ROTATION
	{
		*
		/
		OFF;  OFF
	} = OFF

	GRID
	{
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
	} = OFF

	GAUSSIAN
	{
		REDUCED
		REGULAR
		OFF     ; OFF;  OFF
	} = OFF

	SPECIFICATION 
	{
		*
		OFF
	} = OFF

	LSM        { &_DUMMY&LSM        } = OFF
	TRUNCATION { &_DUMMY&TRUNCATION } = OFF
	INTGRID    { &_DUMMY&INTGRID    } = OFF
	PPENGINE   { &_DUMMY&PPENGINE   } = OFF

    DUPLICATES  
    {
        KEEP
        REMOVE
		OFF
    } = OFF

	EXPECT
	{
		ANY
		*
		OFF ; OFF
	} = OFF

    LOGSTATS
    {
		@
        "   
		OFF
    }

	BRANCH { &_DUMMY&BRANCH } = OFF

	DATABASE 
	{
		@
		/
		OFF
	} 

} ! END OF STAGE

!------------------------------------------------------------------------

REMOVE  ;   REMOVE FDF ENTRIES AND CFS FILES    ;   MARS
{
    
    CLASS  { 

		RESEARCH    ;   RD
		OD

		AUSTRIA		;	AT 
		BELGIUM		;	BE 
		CROATIA		;	HR 
		DENMARK		;	DK 
		FINLAND		;	FI 
		FRANCE		;	FR 
		GERMANY		;	DE 
		GREECE		;	GR 
		HUNGARY		;	HU 
		ICELAND		;	IS 
		IRELAND		;	IE 
		ITALY		;	IT 
		NETHERLANDS	;	NL 
		NORWAY		;	NO 
		PORTUGAL	;	PT 
		SLOVENIA	;	SI 
		SPAIN		;	ES 
		SWEDEN		;	SE 
		SWITZERLAND	;	CH 
		TURKEY		;	TR 
		UNITED KINGDOM;	UK 

	} = RD

    
    PASSWORD
    {
        "   
		@
    } 
    
    EXPVER
    {
		@
        "   
    } = ""
    
    DOMAIN
    {
		&_DUMMY&DOMAIN
    }
    
	DATABASE
	{
		@
		*
		/
		OFF
	} 

    TYPE   { &_DUMMY&TYPE   }

	DATE { 
		*
		TO
		/
	}

    REFDATE 
	{
		&_DUMMY&DATE
    } 

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} 

	TIME {
		*
		TO
		/
	}

    STREAM
	{ 
		&_DUMMY&STREAM 
	}
    
	ORIGIN 
	{
		&_DUMMY&ORIGIN
		/
	}


	SYSTEM 
	{ 	
		&_DUMMY&SYSTEM 
		/
		ALL 
	} 

	METHOD 
	{ 	
		&_DUMMY&METHOD 
		/
		ALL 
	} 

	PRODUCT { &_DUMMY&PRODUCT 
			  OFF }
	SECTION { &_DUMMY&SECTION 
			  OFF }

    LEVTYPE
	{ 
		&_DUMMY&LEVTYPE 
	}

	VOLUME { * }

	CREATED { * }

	LASTACCESS { * }

	EXPR { 
		"
		* 
	}

} ! END OF REMOVE

!------------------------------------------------------------------------
    
!------------------------------------------------------------------------

EXPORT  ;   Write cfs files to tape    ;   MARS
{
    
    VOLSER
    {
        "   
    } = ""
    
    SLOTNO
    {
        "   
    } = ""
    
    CFSPATH
    {
        "   
    } = ""
    
    DENSITY
    {
        *
    } = 6250
    
    RECLEN
    {
        *   
    } = 120
    
    FILESEQ
    {
        *   
    } = 1
    
    SOFTWARE
    {
        "   
    } = ""
    
    FILTER
    {
        "   
    } = "*"
    
    CHECK
    {
        YES ;   Y
        NO  ;   N
    } = NO

}

!------------------------------------------------------------------------


RETRIEVE    ;   Retrieval of data   ;   MARS
{
    
	DATASET [ java_hidden  = TRUE , 
				visible      = true, 
				check        = false,
				priority     = 0]
	{
		@
	}

    CLASS 	[ 	java_control = CHOICE, 
				java_section = ID, 
				marsdoc      = id,
				mars_interface         = menu,
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&CLASS  
	} = OD
    

    TYPE  	[	help = help_multiple_selection, exclusive = True,
				java_control = CHOICE, 
				java_section = ID, 
				marsdoc      = field/image/obs/all,
				mars_interface         = menu,
				java_hidden  = FALSE ] 
	{ 
		&_DUMMY&TYPE   
		*
	} = AN


    STREAM 	[ 	help = help_multiple_selection, exclusive = True,
				java_control = CHOICE, 
				java_section = ID, 
				marsdoc      = id,
				mars_interface         = menu,
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&STREAM 
		*
	} = DA
    

    EXPVER 	[ 	priority     = 1,
				java_control = CHOICE_TEXT_1,
				java_section = ID,
				marsdoc      = id,
				mars_interface         = text,
				java_hidden  = FALSE ]
	{
		@
		1
        "   
        *   
        /
    } = 1
    

    MODEL 	[ 	java_control = CHOICE, 
				java_section = ID, 
				marsdoc      = id,
				mars_interface         = menu,
				hidden       = TRUE,
				java_hidden  = FALSE ]
	{
		&_DUMMY&MODEL
	} = OFF

    REPRES [ java_control = CHOICE, 
			 java_section = ID, 
			 marsdoc      = id,
			 java_hidden = FALSE ] 
	{ 
		&_DUMMY&REPRES 
	} = SH
    
	OBSGROUP [ 	java_hidden  = false , 
				visible      = true, 
				check        = false,
				priority     = 0]
	{ 
		&_DUMMY&OBSGROUP 
		OFF    ; OFF
	} = OFF

    REPORTYPE 
	{ 
		&_DUMMY&REPORTYPE 
	} = OFF

    
	RDBPREFIX [	java_hidden  = TRUE , 
				visible      = false, 
				check        = false,
				priority     = 0]
	{ 
		@
		"
		OFF    ; OFF
	} = OFF
    
    OBSTYPE [ help = help_multiple_selection, # For Metview
			java_control = LIST_2, 
			marsdoc      = obs/image/all,
			mars_interface         = list,
				check        = false,
			java_section = METEO, java_hidden = FALSE, priority = 1 ]
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
    } = S

    LEVTYPE [ java_control = CHOICE, 
			  java_section = ID, 
			  marsdoc      = field/all,
			  mars_interface         = menu,
			  java_hidden = FALSE ] 
	{ 
		&_DUMMY&LEVTYPE 
	} = PL 
    
    LEVELIST [ java_control = CHOICE_TEXT_2, 
			   java_section = ID, 
			   marsdoc      = field/level,
			   mars_interface         = text,
			   java_hidden = FALSE ]
    {
		TO ;    TO
		BY ;    BY 
        ALL ;   ALL
        OFF ;   OFF
        *   
        /   
    } = 1000/850/700/500/400/300
    
    PARAM [ help = help_multiple_selection,  # For Metview
			java_control = LIST_2, 
			marsdoc      = field/all,
			mars_interface         = list,
			java_section = METEO, java_hidden = FALSE ]
    {
        ALL             
        &_DUMMY&PARAM
    } = Z
    
	YEAR [  
			check        = false,
			visible = false
			]
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

	DECADE [
			check        = false,
			visible = false
			]
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

	MONTH [  
			check        = false,
			visible = false
			]
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

    DATE [ java_control = CHOICE_TEXT_2, 
	       java_section = DATE, 
		   marsdoc      = date/all,
		   mars_interface         = text,
		   java_hidden = FALSE ]
    {
		&_DUMMY&DATE
    } = YESTERDAY
    
    VERIFY [ java_control = CHOICE_TEXT_2, 
	       java_section = DATE, 
		   marsdoc      = date/all,
		   mars_interface         = text,
		   hidden      = TRUE,
			check        = false,
		   java_hidden = FALSE ]
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE [ java_control = CHOICE_TEXT_2,
				java_section = DATE,
				marsdoc      = date/all,
				mars_interface         = text,
				java_hidden = FALSE ]
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF

    HDATE [ java_control = CHOICE_TEXT_2,
				java_section = DATE,
				marsdoc      = date/all,
				mars_interface         = text,
				java_hidden = FALSE ]
	{
		&_DUMMY&DATE
		ALL
		OFF          ; OFF
    } = OFF

    FCMONTH [ java_control = CHOICE_TEXT_2,
			java_section = DATE,
			marsdoc      = date/all,
			mars_interface         = text,
			java_hidden = FALSE ]
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD [ java_control = CHOICE_TEXT_2,
			java_section = DATE,
			marsdoc      = date/all,
			mars_interface         = text,
			java_hidden = FALSE ]
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
    TIME [ java_control = CHOICE_TEXT_2, 
		   java_section = DATE, 
		   marsdoc      = date/all,
		   mars_interface         = text,
		   java_hidden = FALSE ]
    {
        *   
        /   
        TO  
        BY  !        6
		ALL 
		12
    } = 12

	LEADTIME [ java_control = CHOICE_TEXT_2,
		   java_section = DATE, 
		   marsdoc      = date/all,
		   mars_interface         = text,
		   java_hidden = FALSE ]
	{
		*
		/
		TO
		OFF
		ALL
	} = OFF

	OPTTIME [ java_control = CHOICE_TEXT_2,
		   java_section = DATE, 
		   marsdoc      = date/all,
		   mars_interface         = text,
		   java_hidden = FALSE ]
	{
		*
		/
		TO
		OFF
		ALL
	} = OFF

	RANGE [ java_control = CHOICE_TEXT_2, 
			java_section = DATE, 
			marsdoc      = date/obs,
			mars_interface         = text,
			java_hidden = FALSE ]
	{
		*
		OFF; OFF
	} = OFF
    
    STEP [ java_control = CHOICE_TEXT_2, 
		   java_section = DATE, 
		   marsdoc      = date/field,
		   mars_interface         = text,
		   java_hidden = FALSE ]
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
!		* [DAY]
!		* [MONTH]
!		* [WEEK]
!		* [VERIFY]
    } = 00
    
    ANOFFSET [ java_control = CHOICE_TEXT_2, 
		   java_section = DATE, 
		   marsdoc      = date/field,
		   mars_interface         = text,
		   java_hidden = FALSE ]
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
		OFF
    }
    
    REFERENCE [ java_control = CHOICE_TEXT_2, 
				java_section = DATE, 
				marsdoc      = date/field,
				mars_interface         = text,
				java_hidden  = FALSE ]
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
		OFF
    } = OFF 

    ENSEMBLE [ 	java_control = CHOICE_TEXT_2, 
				visible      = false, 
			check        = false,
				java_section = OTHER, 
				mars_interface         = text,
				java_hidden  = FALSE ]
    {
        ALL
		TO  
        *   
        /   
        OFF ;  OFF
    } = OFF
    
    CLUSTER [ 	java_control = CHOICE_TEXT_2, 
				visible = false, 
			check        = false,
				java_section = OTHER, 
				java_hidden = FALSE ]
    {
        ALL
		TO  
        *   
        /   
        OFF ;  OFF
    } = OFF
    
    
    PROBABILITY [ 	java_control = CHOICE_TEXT_2, 
					visible = false, 
			check        = false,
					java_section = OTHER, 
					java_hidden = FALSE ]
    {
        ALL 
		TO  
        OFF ; OFF
        *   
        /
    } = OFF

    NUMBER [ java_control = CHOICE_TEXT_2, 
			 java_section = OTHER, 
			 marsdoc      = field/ensemble,
			 mars_interface         = text,
			 java_hidden = FALSE ]
    {
        ALL 
        OFF ;   OFF
		TO  
		BY
        *   
        /
    } = OFF
    
    QUANTILE [ java_control = CHOICE_TEXT_2,
				 java_section = OTHER,
				 marsdoc      = field/ensemble,
				 mars_interface         = text,
			     java_hidden = FALSE ]

    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DOMAIN  [ 	help = help_multiple_selection, # For Metview
				java_control = CHOICE, 
				java_section = OTHER, 
				marsdoc      = id,
				mars_interface         = menu,
				java_hidden = FALSE ] 
    {
	&_DUMMY&DOMAIN
    } = GLOBE

    FREQUENCY [ java_control = CHOICE_TEXT_2, 
				java_section = OTHER, 
				marsdoc      = field/wave,
				mars_interface         = text,
				java_hidden = FALSE ]
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION [ priority = 0, 
				marsdoc  = field/wave,
				java_control = CHOICE_TEXT_2, 
				java_section = OTHER, 
				mars_interface         = text,
				java_hidden = FALSE ]
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIAGNOSTIC  [ 	priority = 1, 
				  	marsdoc  = field/sensitivity,
					mars_interface         = text,
				  	java_control = CHOICE_TEXT_2, 
				  	java_section = OTHER, 
				  	java_hidden = FALSE ]
    {
        ALL 
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION  [ 	java_control = CHOICE_TEXT_2, 
				 	java_section = OTHER, 
				 	marsdoc      = field/sensitivity,
					mars_interface         = text,
				 	java_hidden = FALSE ]
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    CHANNEL [ 	priority = 0, 
			  	java_control = CHOICE_TEXT_2, 
			  	java_section = OTHER, 
			  	marsdoc     = field/brigthness,
				mars_interface         = text,
			  	java_hidden = FALSE ]
	{ 
		ALL
		&_DUMMY&CHANNEL 
	} = OFF

    IDENT
			# For Metview
				   [ help = help_script,                  
				   help_script_command = 
					'/usr/local/lib/metaps/bin/mcs_sat_availability.sh',
			check        = false,
					java_control = CHOICE_TEXT_2, 
					java_section = DATA, 
					marsdoc      = image/obs,
					mars_interface         = list,
					java_hidden = FALSE 
				 ]
											   
    {
		ALL 
		&_DUMMY&IDENT
		"
		@
    }=OFF
    
    ORIGIN 	[ 	java_control = CHOICE, 
				java_section = ID, 
				marsdoc      = field/supplementary,
				mars_interface         = menu,
				java_hidden  = FALSE ]
	{
		&_DUMMY&ORIGIN
	} = OFF

	SYSTEM { &_DUMMY&SYSTEM 
			  OFF } = OFF
	METHOD { &_DUMMY&METHOD 
			  OFF } = OFF
	PRODUCT { &_DUMMY&PRODUCT 
			  OFF } = OFF
	SECTION { &_DUMMY&SECTION 
			  OFF } = OFF
	LATITUDE { @ 
			   OFF } = OFF
	LONGITUDE { @ 
				OFF } = OFF

    SOURCE  [   java_control = CHOICE, 
				java_section = TARGET, 
				marsdoc      = target,
				mars_interface         = text,
				hidden      = TRUE,
			check        = false,
				java_hidden = TRUE ]
    {
		@
        "   
		OFF
    } = ""

    TARGET [ java_control = TEXT, 
			 java_section = TARGET, 
			 marsdoc      = target,
			 mars_interface         = text,
				hidden      = TRUE,
			check        = false,
			 java_hidden = FALSE ]
    {
		@
        "   
		OFF
    } = ""

    LOGSTATS [ java_control = TEXT,
             java_section = TARGET,
             marsdoc      = target,
             mars_interface         = text,
                hidden      = TRUE,
            check        = false,
             java_hidden = FALSE ]
    {
		@
        "   
		OFF
    }

    TRANSFER [ hidden      = TRUE, check        = false ]
    {
		HANDLE
		DATA
		OFF
    }

    FIELDSET  [ java_control = CHOICE, 
				java_section = TARGET, 
				marsdoc      = target,
			 	mars_interface         = text,
				priority     = 1,
				hidden      = TRUE,
			check        = false,
				java_hidden = TRUE ]
    {
        @
		OFF
    }
    
    CFSPATH  [ java_control = TEXT, 
			   java_section = TARGET, 
			   hidden      = TRUE,
			check        = false,
			   java_hidden = TRUE ]
    {
        "   
    } = ""
    
    FORMAT  [ java_control = CHOICE, 
	          java_section = DATA, 
				hidden      = TRUE,
			check        = false,
			  java_hidden = FALSE ]
    {
        PACKED      ;   P
        UNPACKED    ;   U
        GRIB EDITION 1 ;   GRIB1
        GRIB EDITION 2 ;   GRIB2
		NETCDF
		ODB
		ASCII
    } = P
    
    DISP [ java_control = CHOICE,
			java_section = DATA,
			hidden      = TRUE,
			check        = false,
			java_hidden = FALSE ]

    {
        NEW ;   N
        OLD ;   OLD
		REMOVE
		OFF
    } = OFF
    
    RESOL [ help = help_multiple_selection,  # For Metview
			check        = false,
			java_control = CHOICE_TEXT_2, 
			java_section = DATA, 
			marsdoc      = pproc/field,
			mars_interface         = menu,
			java_hidden = FALSE ]
    {
        ARCHIVED VALUE       ;   AV
		AUTOMATIC RESOLUTION ;   AUTO
		REDUCED GAUSSIAN 128 ;   N128
		REDUCED GAUSSIAN 160 ;   N160
		REDUCED GAUSSIAN 200 ;   N200
		OFF                  ;   OFF
		319
		213
		106
		63
        *   
    } = AUTO
    
    ACCURACY [ 	java_control = CHOICE_TEXT_1, 
			   	java_section = DATA, 
			   	marsdoc      = pproc/field,
				mars_interface         = text,
			check        = false,
			   	java_hidden = FALSE ]
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW     ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = N
    
    STYLE [ 	java_control = CHOICE_TEXT_1, 
			   	java_section = DATA, 
			   	marsdoc      = pproc/field,
				mars_interface         = text,
			    check        = false,
			   	java_hidden = FALSE ]
    {
        DISSEMINATION  
        OFF   
    } = OFF
    
	INTERPOLATION [ java_control = CHOICE_TEXT_1, 
			   	java_section = DATA, 
			   	marsdoc      = pproc/field,
				mars_interface         = text,
			    check        = false,
			   	java_hidden = FALSE ]
	{
		NEAREST NEIGHBOUR
		NEAREST LSM
		BILINEAR
		LINEAR
		LINEAR FIT
		CUBIC
		AVERAGE WEIGHTED
		AVERAGE
		"
		OFF
	} = OFF

    AREA  [ help = help_multiple_selection,			# For Metview
    		java_control = CHOICE_TEXT_2, 
			java_section = DATA, 
			marsdoc      = pproc/obs,
			mars_interface         = text,
			check        = false,
			java_hidden = FALSE ]
    {
        GLOBE                           ;   G
        EUROPE                          ;   E 
        *   
        /   
		OFF
    } = G

	LOCATION [ java_hidden  = TRUE , 
				visible      = false, 
				check        = false,
				priority     = 0]
	{
		*
        /   
        OFF     ;  OFF
	} = OFF

    BLOCK  [ 	java_control = CHOICE_TEXT_2, 
			 	java_section = DATA, 
			 	marsdoc      = obs,
				mars_interface         = text,
			check        = false,
			 	java_hidden = FALSE ]
    {
        OFF     ;  OFF
        /   
        *       
    }=OFF

    INSTRUMENT  [ 	java_control = CHOICE_TEXT_2, 
			 	java_section = DATA, 
			 	marsdoc      = obs,
				mars_interface         = text,
			check        = false,
			 	java_hidden = FALSE ]
    {
		&_DUMMY&INSTRUMENT
    }=OFF

    FILTER  [ 	java_control = CHOICE_TEXT_2, 
			 	java_section = DATA, 
			 	marsdoc      = obs,
				mars_interface         = text,
				priority     = 0,
			check        = false,
			 	java_hidden = FALSE ]
    {
		@
		OFF
    }=OFF

	ROTATION [ java_control = CHOICE_TEXT_2,
			   java_section = DATA,
			   marsdoc      = pproc/field,
				mars_interface         = text,
			check        = false,
			   java_hidden = FALSE ]
	{
		*
		/
		OFF;  OFF
	} = OFF

	FRAME [ marsdoc      = pproc/field,
			check        = false,
			mars_interface         = text ]
	{
		*
		OFF;  OFF
	} = OFF

	BITMAP [ marsdoc      = pproc/field,
			check        = false,
			mars_interface         = text ]
	{
		OFF ; OFF
		@
		"
	}  = OFF

    GRID  [ java_control = CHOICE_TEXT_2, 
			java_section = DATA, 
			marsdoc      = pproc/field,
			mars_interface         = text,
			check        = false,
			exact_match = true,
			java_hidden = FALSE ]
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
	GAUSSIAN [  help = help_multiple_selection,  # For Metview
				java_control = CHOICE_TEXT_2, 
				java_section = DATA, 
				marsdoc      = pproc/field,
				mars_interface         = text,
			check        = false,
				java_hidden = FALSE ]
	{
		REDUCED
		REGULAR
		OFF     ;  OFF
	} = OFF

	SPECIFICATION [ marsdoc      = pproc/field,
			check        = false,
					mars_interface         = text ]
	{
		*
		OFF
	} = OFF

	PACKING [ help = help_multiple_selection,  # For Metview
			  java_control = CHOICE_TEXT_2,
			  java_section = DATA,
			  marsdoc      = pproc/field,
			  hidden       = true,
			check        = false,
			  mars_interface         = text,
			  java_hidden = FALSE ]
	{
		SI   ; SIMPLE
		CO   ; COMPLEX
		SO   ; SECOND ORDER
		AV   ; ARCHIVED VALUE
		OFF
	} = OFF


    PADDING  [ 	help = help_multiple_selection,  # For Metview
			check        = false,
				java_control = CHOICE, 
				java_section = OTHER, 
				marsdoc      = control,
				mars_interface    = text,
				java_hidden = FALSE ]
    {
		&_DUMMY&PADDING
		OFF
    } = OFF
    

    DUPLICATES  [ 	java_control = CHOICE, 
				  	java_section = OTHER, 
				  	marsdoc      = obs,
					mars_interface    = on_off,
			check        = false,
				  	java_hidden = FALSE ]
    {
        KEEP
        REMOVE
    } = KEEP
    
    LAUNCH  [ java_control = TEXT, 
			  java_section = OTHER, 
			  hidden      = TRUE,
			check        = false,
			  java_hidden = FALSE ]
    {
        "   
    } = ""
    
	JOB
	{
		"
		OFF
	} = OFF

    USE  [ 	java_control=CHOICE, 
	       	java_section=OTHER, 
		   	marsdoc     = control,
			mars_interface         = menu,
			hidden     = TRUE,
			check        = false,
		   	java_hidden=FALSE ]
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
    } = NORMAL
    
    PASSWORD  [ java_control = CHOICE_TEXT_1, 
				java_section = OTHER, 
				hidden      = TRUE,
			check        = false,
				java_hidden = FALSE ]
    {
        "   
		@
        OFF ;   OFF
    } = OFF
    
    COSTONLY  [ java_control = CHOICE, 
				java_section = OTHER, 
				hidden      = TRUE,
			check        = false,
				java_hidden = FALSE ]
    {
        YES ;   Y
        NO  ;   N
    } = N
    
	OPTIMISE [ java_control = CHOICE, 
				java_section = OTHER, 
				hidden      = TRUE,
			check        = false,
				java_hidden = FALSE ]
    {
		ON
		OFF
	} = OFF

    PROCESS  [ java_control = CHOICE, 
			   java_section = OTHER, 
			   hidden       = TRUE,
			check        = false,
			   java_hidden = FALSE ]
    {
		LOCAL 
		SERVER
        OFF ;   OFF
    } = OFF

	BRANCH [ java_control = CHOICE, 
			 java_section = OTHER, 
			 hidden       = TRUE,
			 check        = false,
			 java_hidden = FALSE ]
	{ &_DUMMY&BRANCH } = OFF

	DATABASE  [ java_control = CHOICE, 
				java_section = OTHER, 
				marsdoc      = control,
			check        = false,
				priority = 1,
				java_hidden = TRUE ]
	{
		@
		/
		OFF
	}

	EXPECT [    priority = 0,
				java_control = CHOICE_TEXT_2, 
				java_section = OTHER, 
				marsdoc      = control,
			check        = false,
				java_hidden = FALSE]
	{
		ANY
		*
		OFF ; OFF
	} = OFF

	_VERSION [ java_control = CHOICE, 
			   java_section = OTHER, 
			   hidden       = TRUE,
			check        = false,
			   java_hidden = FALSE ]
	{
		*
	} = 2.0

	LSM        { &_DUMMY&LSM        } = OFF
	TRUNCATION { &_DUMMY&TRUNCATION } = OFF
	INTGRID    { &_DUMMY&INTGRID    } = OFF
	PPENGINE   { &_DUMMY&PPENGINE   } = OFF


} ! END OF RETRIEVE

COMPUTE ; X ; METVIEW
{
    FORMULA {
		@
    } = ""

    FIELDSET {
        @
    } = OUT

    ACCURACY 
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = N

	TARGET 
	{
		@
		"
		OFF
	} = ""
}

WRITE ; X; METVIEW
{
    FIELDSET {
    @
    } = OUT

    LOGSTATS
    {
		@
        "   
		OFF
    }

    TARGET  {
		@
        "
    } = ""
}

READ ; X; METVIEW
{
    FIELDSET [ visible = false ] {
    @
    } = OUT

	READ_DATA_FROM [ visible = false ]
	{
		FILE
		METVIEW_ICON
	} = FILE


    SOURCE  [ visible = always, help = help_file_box ]
	{
		@
		OFF
    } = OFF

    LOGSTATS
    {
		@
        "   
		OFF
    }

	DATA
		[
			interface = icon,
			class           = GRIB,
			exclusive       = true
		]
	{
		@
	}


	CFSPATH {
		@
		OFF
	} = OFF

    ORDER [ label = 'Field Ordering' ] {
	AS IS  ; 0
        SORTED ; 1
    } = AS IS

	CLASS  { &_DUMMY&CLASS 
			 ANY ; ANY
			 } = ANY

	STREAM [ help = help_multiple_selection, exclusive = True ]
		{ &_DUMMY&STREAM 
			 ANY ; ANY
			 *
			 } = ANY

    TYPE   [ help = help_multiple_selection, exclusive = True ]
		{ 
		ANY ; ANY
		&_DUMMY&TYPE   
		*
	} = ANY
    
    MODEL   { 
		ANY ; ANY
		&_DUMMY&MODEL   
	} = ANY
    
    LEVTYPE
    {
		ANY ; ANY
		&_DUMMY&LEVTYPE
    } = ANY
    
    LEVELIST
    {
        ANY ; ANY
		TO  ; TO
		BY  ; BY 
        OFF ; OFF;   OFF
        *   
        /   
    } = ANY
    
    PARAM [ help = help_multiple_selection ] # For Metview
    {
        ANY             ;   ANY
        &_DUMMY&PARAM
    } = ANY
    
    DATE
    {
		ANY             ;   ANY
		&_DUMMY&DATE   
    } = ANY
    
    VERIFY 
	{
		ANY             ;   ANY
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE 
	{
		ANY             ;   ANY
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		ANY             ;   ANY
		&_DUMMY&DATE 
		ALL
	} = OFF

    FCMONTH 
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
    TIME
    {
		ANY
        *   
        /   
        TO  ;   TO
        BY  ;   BY           !        6
    } = ANY
    
	LEADTIME
	{
		*
		/
		TO
		OFF
		ANY
	} = ANY

	OPTTIME
	{
		*
		/
		TO
		OFF
		ANY
	} = ANY

    REFERENCE 
    {
        ANY ;   ANY
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    } = ANY 

    STEP
    {
        ANY ;   ANY
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    } = ANY
    
    ANOFFSET
    {
        ANY ;   ANY
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    } = ANY
    
	RANGE 
	{
		*
		ANY
	} = ANY
    
    ACCURACY 
    {
		ANY     ;   ANY
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = N
    
	STYLE
    {
        DISSEMINATION  
        OFF   
		ANY
    } = ANY

	INTERPOLATION
	{
		NEAREST NEIGHBOUR
		NEAREST LSM
		BILINEAR
		LINEAR
		LINEAR FIT
		CUBIC
		AVERAGE WEIGHTED
		AVERAGE
		"
		OFF
		ANY
	} = ANY

    AREA
    {
		ANY ; ANY
        GLOBE               ;  GLOBE;  G
        EUROPE              ;  EUROPE; E
        *   
        /   
    } = ANY

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

	RESOL 
	{
        ARCHIVED VALUE       ;   AV
		AUTOMATIC RESOLUTION ;   AUTO
		319
		213
		106
        *   
		ANY ; ANY
	} = AUTO

	ROTATION
	{
		ANY     ; ANY
		*
		/
	} = ANY

    GRID [ exact_match = true ]
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
        ANY     ; ANY
    } = ANY

	GAUSSIAN 
	{
		REDUCED
		REGULAR
		OFF     ; OFF;  OFF
	} = OFF

	SPECIFICATION 
	{
		*
		OFF
	} = OFF

	PACKING
	{
		SI   ; SIMPLE
		CO   ; COMPLEX
		SO   ; SECOND ORDER
		AV   ; ARCHIVED VALUE
		OFF
	} = OFF

	TARGET [ visible = false ]
	{
		@
		"
		OFF
	} = OFF

    ENSEMBLE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    CLUSTER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    
    PROBABILITY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
		ANY
    } = ANY
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
		ANY
    } = ANY

    FREQUENCY
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
		ANY
    } = ANY
    
    DIRECTION 
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
		ANY
    } = ANY
    
    DIAGNOSTIC
    {
        ALL 
        OFF ;   OFF
        *   
        /
		ANY
    } = ANY

    ITERATION
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
		ANY
    } = ANY
    
    CHANNEL { &_DUMMY&CHANNEL 
			 ANY ; ANY
			 } = ANY

    IDENT { &_DUMMY&IDENT 
			 ANY ; ANY
			 } = ANY

    INSTRUMENT { &_DUMMY&INSTRUMENT 
			 ANY ; ANY
			 } = ANY

    FILTER  
    {
		@
		ANY ; ANY
    }= ANY

! For compatibility with RETRIEVE. They are unset in Mars rules

	REPRES { &_DUMMY&REPRES
			 ANY ; ANY
			 } = ANY 

    ORIGIN 	{ &_DUMMY&ORIGIN
			 ANY ; ANY
			 } = ANY 

    PADDING  
    {
		ANY  ; ANY
		&_DUMMY&PADDING
    } = ANY
    
    DOMAIN 
    {
	&_DUMMY&DOMAIN
	ANY
    } = ANY
    
	SYSTEM { &_DUMMY&SYSTEM 
			  ANY } = ANY
	METHOD { &_DUMMY&METHOD 
			  ANY } = ANY
	PRODUCT { &_DUMMY&PRODUCT 
			  ANY } = ANY
	SECTION { &_DUMMY&SECTION 
			  ANY } = ANY
	LATITUDE { 
		@ 
		ANY
	} = ANY

	LONGITUDE { 
		@ 
		ANY
	} = ANY

    EXPVER{
		@
		1
		2
		11
		12
        "   
        *   
		ANY ; ANY
    } = ANY

	LSM        { &_DUMMY&LSM        } = OFF
	TRUNCATION { &_DUMMY&TRUNCATION } = OFF
	INTGRID    { &_DUMMY&INTGRID    } = OFF

} ! END OF READ

DATA ; X ; METVIEW
{
    FIELDSET [ visible = false ] {
		@
	}

	PATH {
		@
	}

	OFFSET {
		*
		/
	}

	LENGTH {
		*
		/
	}

	INDEX {
		*
		/
	}

}

FLUSH ;   Flushes data   ;   MARS
{

    CLASS  { &_DUMMY&CLASS  }

    TYPE   { &_DUMMY&TYPE   }

    STREAM { &_DUMMY&STREAM }

    MODEL  { &_DUMMY&MODEL }

    ORIGIN { &_DUMMY&ORIGIN }

	SYSTEM  { &_DUMMY&SYSTEM  }

	METHOD  { &_DUMMY&METHOD  }

	PRODUCT { &_DUMMY&PRODUCT }

	SECTION { &_DUMMY&SECTION }

	LATITUDE { @ }

	LONGITUDE { @ }

    EXPVER  [ priority = 1 ]
    {
		@
        "       
        *       
    }
    
    LEVTYPE  { &_DUMMY&LEVTYPE }
    
    LEVELIST  
    {
		TO ; TO
		BY ; BY 
        OFF ;   OFF
        *       
        /       
    }
    
    REPRES   { &_DUMMY&REPRES }
    
    DOMAIN 
    {
	&_DUMMY&DOMAIN
    }
    
    OBSTYPE { ALL &_DUMMY&OBSTYPE }
    
	OBSGROUP { ALL
	&_DUMMY&OBSGROUP } 
    
    PARAM { &_DUMMY&PARAM }
    
	CHANNEL { &_DUMMY&CHANNEL }

	IDENT { &_DUMMY&IDENT }

	INSTRUMENT { &_DUMMY&INSTRUMENT }

	FILTER { @ }

    DATE
    {
        JANUARY     ;   JAN
        FEBRUARY    ;   FEB
        MARCH       ;   MAR
        APRIL       ;   APR
        MAY     ;   MAY
        JUNE        ;   JUN
        JULY        ;   JUL
        AUGUST      ;   AUG
        SEPTEMBER   ;   SEP
        OCTOBER     ;   OCT
        NOVEMBER    ;   NOV
        DECEMBER    ;   DEC
        *   
         CURRENT DATE ; 0
         YESTERDAY    ; -1
		 TO ; TO
		 /
    }
    
    REFDATE 
	{
		&_DUMMY&DATE
    } 

    FCMONTH 
	{
        *   
		ALL
	}

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} 

    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY    !                               6
    }
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} 

	OPTTIME
	{
		*
		/
		TO
		OFF
	} 

	RANGE 
	{
		*
		OFF; OFF
	} 

    REFERENCE 
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY        
		OFF
    }

    STEP
    {
        *   
    }
    
    ANOFFSET
    {
        *   
		OFF
    }
    
    ENSEMBLE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    }
    
    CLUSTER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    }
    
    
    PROBABILITY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    }
    
    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } 
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } 

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    }

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    }
    
    FREQUENCY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  
        *   
        /
    } 
    
    DIRECTION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  
        *   
        /
    }
    
    SOURCE
    {
		@
		/
        "   
    }
    
    DISP
    {
        NEW ;   N
        OLD ;   OLD
    } 
    
    AREA
    {
        GLOBE   ;   G
        EUROPE  ;   E
    }
    
	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    RESOL
    {
        /
        *   
    }

    GRID
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
        OFF     ; OFF;  OFF
    }
    
    PASSWORD
    {
        "   
    } 

	EXPECT 
	{
		*
		OFF ; OFF
		ANY
	} = OFF

	DATABASE
	{
		@
		/
		OFF
	} 

! Only for FLUSH

	WAIT
	{
		TRUE
		FALSE
	} = FALSE

	DECACHE
	{
		TRUE
		FALSE
	} = FALSE

} ! END OF FLUSH


ATTACH ;   attaches data   ;   MARS
{

    CLASS  { &_DUMMY&CLASS  } = OD

    TYPE   { &_DUMMY&TYPE   } = AN

    STREAM { &_DUMMY&STREAM } = DA

    MODEL  { &_DUMMY&MODEL }  = OFF

    ORIGIN { &_DUMMY&ORIGIN } = OFF

    EXPVER  
    {
		@
        "       
        *       
    } = 1
    
    LEVTYPE  { &_DUMMY&LEVTYPE } = PL
    
    LEVELIST  
    {
		TO ; TO
		BY ; BY 
        OFF ;   OFF
        *       
        /       
    } = 1000/850/700/500/400/300
    
    REPRES   { &_DUMMY&REPRES } = SH
    
    DOMAIN 
    {
	&_DUMMY&DOMAIN
    } = G
    
    OBSTYPE { ALL
	&_DUMMY&OBSTYPE } = S
    
    PARAM { &_DUMMY&PARAM } = Z
    
    DATE
    {
        JANUARY     ;   JAN
        FEBRUARY    ;   FEB
        MARCH       ;   MAR
        APRIL       ;   APR
        MAY     ;   MAY
        JUNE        ;   JUN
        JULY        ;   JUL
        AUGUST      ;   AUG
        SEPTEMBER   ;   SEP
        OCTOBER     ;   OCT
        NOVEMBER    ;   NOV
        DECEMBER    ;   DEC
        *   
         CURRENT DATE ; 0
         YESTERDAY    ; -1
		 TO ; TO
		 /
    } = CURRENT DATE
    
    REFDATE 
	{
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY    !                               6
    } = 12
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

    STEP
    {
        *   
    } = 00
    
    ANOFFSET
    {
        *   
		OFF
    }
    
    ENSEMBLE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    CLUSTER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    
    PROBABILITY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    SOURCE
    {
		@
        "   
    } = ""
    
	NAME
	{
		"
	} = ""

    DISP
    {
        NEW ;   N
        OLD ;   OLD
    } = NEW
    
    AREA
    {
        GLOBE   ;   G
        EUROPE  ;   E
    } = G
    
	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    RESOL
    {
        /
        *   
    }
    
    LAUNCH
    {
        "   
    } = ""
    
	JOB
	{
		"
		OFF
	} = OFF

    USE
    {
        FREQUENT    ;   F
        INFREQUENT  ;   I
        NORMAL      ;   N
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
    } = N
    
    PASSWORD
    {
        "   
    } = ""

	DATABASE
	{
		@
		/
		OFF
	}

	WAIT {
		YES
		NO
	} = NO

} ! END OF ATTACH


STORE ;   Stores files   ;   MARS
{

    CLASS  { &_DUMMY&CLASS  } = OD

    TYPE   { &_DUMMY&TYPE   } = AN

    STREAM { &_DUMMY&STREAM } = DA

    MODEL  { &_DUMMY&MODEL  } = OFF

    ORIGIN { &_DUMMY&ORIGIN } = OFF

    EXPVER  [ priority = 1 ]
    {
		@
        "       
        *       
    } = 1
    
    LEVTYPE { &_DUMMY&LEVTYPE } = PL 
    
    LEVELIST  
    {
		TO ; TO
		BY ; BY 
        OFF ;   OFF
        *       
        /       
    } = 1000/850/700/500/400/300
    
    REPRES { &_DUMMY&REPRES } = SH
    
    DOMAIN 
    {
	&_DUMMY&DOMAIN
    } = G
    
    OBSTYPE { ALL
	&_DUMMY&OBSTYPE } = S

	OBSGROUP { ALL
	&_DUMMY&OBSGROUP } = CONVENTIONAL	
    
    PARAM { &_DUMMY&PARAM } = Z
    
    DATE 
	{
		&_DUMMY&DATE
    } = CURRENT DATE
    
    REFDATE 
	{
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY    !                               6
    } = 12
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

    STEP
    {
        *   
    } = 00
    
    ANOFFSET
    {
        *   
		OFF
    }
    
    ENSEMBLE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    CLUSTER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    
    PROBABILITY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
        *   
        /
    } = OFF
    
    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    SOURCE
    {
		@
        "   
    } = ""
    
    DISP
    {
        NEW ;   N
        OLD ;   OLD
    } = NEW
    
    AREA
    {
        GLOBE   ;   G
        EUROPE  ;   E
    } = G
    
	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    RESOL
    {
        /
        *   
    }
    
    PASSWORD
    {
        "   
    } = ""

	DATABASE
	{
		@
		/
		OFF
	} 

	EXPECT [ priority = 0 ]
	{
		ANY
		*
		OFF ; OFF
	} = OFF

	NAME
	{
		@
	} = ""

} ! END OF STORE

REGISTER    ;   Registering of keywords   ;   MARS
{
    
    CLASS 	[ 	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&CLASS  
	} = OD
    

    TYPE  	[	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ] 
	{ 
		&_DUMMY&TYPE   
	} = AN


    STREAM 	[ 	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&STREAM 
	} = DA
    

    EXPVER 	[ 	priority     = 1,
				java_control = CHOICE_TEXT_1,
				java_section = ID,
				java_hidden  = FALSE ]
	{
		@
		1
		2
		11
		12
        "   
        *   
    } = 1

    LEVTYPE [ java_control = CHOICE, java_section = ID, java_hidden = FALSE ] 
	{ 
		&_DUMMY&LEVTYPE 
	} = PL 
    

	NAME
	{
		@
	} = ""

	ATTRIBUTES
	{
		DATE
		TIME
		OBSTYPE
		/
	} = DATE

	DATABASE
	{
		@
		/
		OFF
	}

} ! END OF REGISTER


FETCH    ;   Fetch data   ;   MARS
{
    
    CLASS 	[ 	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&CLASS  
	} = OD
    

    TYPE  	[	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ] 
	{ 
		&_DUMMY&TYPE   
	} = AN


    STREAM 	[ 	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ]
	{ 
		&_DUMMY&STREAM 
	} = DA
    
    ORIGIN 	[ 	java_control = CHOICE, 
				java_section = ID, 
				java_hidden  = FALSE ]
	{
		&_DUMMY&ORIGIN
	} = OFF

    EXPVER 	[ 	priority     = 1,
				java_control = CHOICE_TEXT_1,
				java_section = ID,
				java_hidden  = FALSE ]
	{
		@
		1
		2
		11
		12
        "   
        *   
    } = 1
    

    LEVTYPE [ java_control = CHOICE, java_section = ID, java_hidden = FALSE ] 
	{ 
		&_DUMMY&LEVTYPE 
	} = PL 
    
    LEVELIST [ java_control = CHOICE_TEXT_2, java_section = ID, java_hidden = FALSE ]
    {
		TO ; TO
		BY ; BY 
        ALL ;   ALL
        OFF ; OFF;   OFF
        *   
        /   
    } = 1000/850/700/500/400/300
    
    REPRES [ java_control = CHOICE, java_section = ID, java_hidden = FALSE ] 
	{ 
		&_DUMMY&REPRES 
	} = SH
    
    DOMAIN  [ help = help_multiple_selection, # For Metview
				java_control = CHOICE, java_section = OTHER, java_hidden = FALSE ] 
    {
	&_DUMMY&DOMAIN
    } = G

    OBSTYPE [ help = help_multiple_selection, # For Metview
			java_control = LIST_2, java_section = METEO, java_hidden = FALSE ]
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
    } = S

    PARAM [ help = help_multiple_selection,  # For Metview
			java_control = LIST_2, java_section = METEO, java_hidden = FALSE ]
    {
        ALL             ;   ALL
        &_DUMMY&PARAM
    } = Z
    
    DATE [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
    {
		&_DUMMY&DATE
    } = CURRENT DATE
    
    REFDATE [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
	{
		&_DUMMY&DATE
    } = OFF

    HDATE [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
	{
		&_DUMMY&DATE
		ALL
    } = OFF

    TIME [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
    {
!		00
!		03
!		06
!		09
!		12
!		15
!		18
!		21
        *   
        /   
        TO  ;   TO
        BY  ;   BY           !        6
		ALL ;   ALL
    } = 12

	LEADTIME [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
	{
		*
		/
		TO
		OFF
	} = OFF

	RANGE 
	{
		*
		OFF; OFF
	} = OFF
    
    STEP [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    } = 00
    
    ANOFFSET [ java_control = CHOICE_TEXT_2, java_section = DATE, java_hidden = FALSE ]
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    }
    
    ENSEMBLE [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } = OFF
    
    CLUSTER [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } = OFF
    
    
    PROBABILITY [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
		TO  ; TO
        OFF ;   OFF
        *   
        /
    } = OFF

    NUMBER [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF
    
    QUANTILE [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DIAGNOSTIC  [ priority = 1, java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION  [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    FREQUENCY [ java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION [ priority = 0, java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE ]
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    TARGET [ java_control = TEXT, java_section = TARGET, java_hidden = FALSE ]
    {
		@
        "   
		OFF
    } = ""

    FIELDSET  [ java_control = CHOICE, java_section = TARGET, java_hidden = TRUE ]
    {
        @
		OFF
    }
    
    CFSPATH  [ java_control = TEXT, java_section = TARGET, java_hidden = FALSE ]
    {
        "   
    } = ""
    
    FORMAT  [ java_control = CHOICE, java_section = DATA, java_hidden = FALSE ]
    {
        PACKED      ;   P
        UNPACKED    ;   U
        GRIB EDITION 1 ;   GRIB1
        GRIB EDITION 2 ;   GRIB2
		NETCDF
		ODB
		ASCII
    } = P
    
    RESOL [ java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE ]
    {
        ARCHIVED VALUE  ;   AV
        OFF     ;   OFF
        *   
        /
    } = AV
    
    ACCURACY [ java_control = CHOICE_TEXT_1, java_section = DATA, java_hidden = FALSE ]
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = N
    
    AREA  [ help = help_multiple_selection,			# For Metview
    		java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE ]
    {
        GLOBE               ;  GLOBE;  G
        EUROPE              ;  EUROPE; E
        *   
        /   
    } = G

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    BLOCK  [ java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE ]
    {
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF

    IDENT
			# For Metview
				   [ help = help_script,                  
				   help_script_command = 
					'/usr/local/lib/metaps/bin/mcs_sat_availability.sh',
					java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE 
				 ]
											   
    {
		ALL 
        METEOSAT 3 ; MS3 ; 50
        METEOSAT 4 ; MS4 ; 51
        METEOSAT 5 ; MS5 ; 52
        METEOSAT 6 ; MS6 ; 53
        METEOSAT 7 ; MS7 ; 54
		DMSP 10 ; 204
		DMSP 13 ; 246
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF
    
	ROTATION [ java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE ]
	{
		*
		/
		OFF;  OFF
	} = OFF

    GRID  [ java_control = CHOICE_TEXT_2, java_section = DATA, java_hidden = FALSE ]
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
    DUPLICATES  [ java_control = CHOICE, java_section = OTHER, java_hidden = FALSE ]
    {
        KEEP
        REMOVE
    } = KEEP
    
    LAUNCH  [ java_control = TEXT, java_section = OTHER, java_hidden = FALSE ]
    {
        "   
    } = ""
    
	JOB
	{
		"
		OFF
	} = OFF

    USE  [ java_control=CHOICE, java_section=OTHER, java_hidden=FALSE ]
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
    } = NORMAL
    
    PASSWORD  [ java_control = CHOICE_TEXT_1, java_section = OTHER, java_hidden = FALSE ]
    {
        "   
        OFF ;   OFF
    } = OFF
    
    COSTONLY  [ java_control = CHOICE, java_section = OTHER, java_hidden = FALSE ]
    {
        YES ;   Y
        NO  ;   N
    } = N
    
    PROCESS  [ java_control = CHOICE, java_section = OTHER, java_hidden = FALSE ]
    {
		LOCAL ; LOCAL
		SERVER
        OFF ;   OFF
    } = LOCAL


	DATABASE  [ java_control = CHOICE, java_section = OTHER, java_hidden = FALSE ]
	{
		@
		OFF
	}

	EXPECT [ priority = 0,
				java_control = CHOICE_TEXT_2, java_section = OTHER, java_hidden = FALSE]
	{
		ANY
		*
		OFF ; OFF
	} = OFF

	_VERSION {
		*
	} = 1.3

	NAME {
		@
	}
    
} ! END OF FETCH

!------------------------------------------------------------------------

BROWSE    ;   LIST FDF ENTRIES AND CFS FILES  ;   MARS
{
    
    CLASS  
	{ 
		&_DUMMY&CLASS  
		/ 
		ALL
	} 
    
    TYPE   
	{ 
		&_DUMMY&TYPE  
		/  
		ALL
	} 

    STREAM 
	{ 
		&_DUMMY&STREAM 
		/ 
		ALL
	} 
    
	ORIGIN 
	{
		&_DUMMY&ORIGIN
		/
		ALL
	}

    EXPVER{
		@
		/
		ALL
    } 
    
    LEVTYPE 
	{ 
		&_DUMMY&LEVTYPE 
		/ 
		ALL
	}
    
    LEVELIST
    {
		TO ; TO
		BY ; BY 
        ALL ;   ALL
        OFF ; OFF;   OFF
        *   
        /   
    }
    
    REPRES { 
		&_DUMMY&REPRES 
		/ 
		ALL
	}
    
    DOMAIN  
    {
		&_DUMMY&DOMAIN
		/
		ALL
    } 

    OBSTYPE 
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
		/
    } 

	OBSGROUP { ALL
	&_DUMMY&OBSGROUP }
    
    DUPLICATES  {
        KEEP
        REMOVE
    } = KEEP
    
    PARAM 
    {
        ALL             ;   ALL
        &_DUMMY&PARAM
		/
    }
    
    CHANNEL 
	{ 	
		ALL             ; ALL
		&_DUMMY&CHANNEL 
	} 

    IDENT 
	{ 	
		ALL             ; ALL
		&_DUMMY&IDENT 
	} 

    INSTRUMENT 
	{ 	
		ALL             ; ALL
		&_DUMMY&INSTRUMENT 
	} 

    DATE
    {
		&_DUMMY&DATE
		ALL
    } 

    REFDATE 
	{
		&_DUMMY&DATE
		ALL
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    TIME
    {
        *   
        /   
        TO  ;   TO
        BY  ;   BY           !        6
		ALL ;   ALL
    }
    
	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

    REFERENCE 
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    }

    STEP
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
    }
    
    ANOFFSET
    {
        ALL ;   ALL
        *   
        /   
        TO  ;   TO
        BY  ;   BY        !           12
		OFF
    }
    
    ENSEMBLE
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } 
    
    CLUSTER
    {
        ALL
		TO  ; TO
        *   
        /   
        OFF ; OFF;  OFF
    } 
    
    
    PROBABILITY
    {
        ALL ;   ALL
		TO  ; TO
        OFF ;   OFF
        *   
        /
    }

    NUMBER
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    }
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } 

    DIAGNOSTIC
    {
        ALL ;   ALL
        OFF ;   OFF
        *   
        /
    } 

    ITERATION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    }

    FREQUENCY
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION
    {
        ALL ;   ALL
        OFF ;   OFF
		TO
        *   
        /
    }
    
	SHOW
	{
		@
		/
	}

	HIDE
	{
		@
		/
	}

 
    TARGET
    {
		@
        "   
		OFF
    }

	DATABASE {
		@
		/
		OFF
	}

	RANGE 
	{
		*
		OFF; OFF
	}


    SOURCE
    {
		@
        "   
    } 

    FIELDSET  
    {
        @
    }
    
    CFSPATH  
    {
        "   
    }
    
    FORMAT  
    {
        PACKED      ;   P
        UNPACKED    ;   U
        GRIB EDITION 1 ;   GRIB1
        GRIB EDITION 2 ;   GRIB2
		NETCDF
		ODB
		ASCII
		OFF         ;   OFF
    } 
    
    RESOL 
    {
		OFF                  ;   OFF
        *   
    } = OFF
    
    ACCURACY 
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = OFF
    
    AREA  
    {
        GLOBE               ;  GLOBE;  G
        EUROPE              ;  EUROPE; E
        *   
        /   
		OFF; OFF
    } = OFF

	FRAME 
	{
		*
		OFF; OFF
	} = OFF

	BITMAP 
	{
		OFF ; OFF
		@
		"
	} = OFF

    BLOCK  
    {
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF

    IDENT
    {
        OFF     ; OFF;  OFF
        /   
        *       
    }=OFF
    
    GRID  
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
	GAUSSIAN 
	{
		REDUCED
		REGULAR
		OFF     ; OFF;  OFF
	} = OFF

	SPECIFICATION 
	{
		*
		OFF
	} = OFF

    LAUNCH  
    {
        "   
    } = ""
    
	JOB
	{
		"
		OFF
	} = OFF

    USE  
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
		OFF; OFF
    } = OFF
    
    PASSWORD  
    {
        "   
        OFF ;   OFF
    } = OFF
    
    COSTONLY  
    {
        YES ;   Y
        NO  ;   N
		OFF ;   OFF
    } = OFF
    
    PROCESS  
    {
		LOCAL ; LOCAL
		SERVER
        OFF ;   OFF
    } = OFF


	EXPECT 
	{
		ANY
		*
		OFF ; OFF
	} = OFF



} ! END OF BROWSE


GET    ;   GET ;   MARS
{
	TAPE
	{
		@
	}

    TARGET
    {
		@
        "   
		OFF
    }

	DATABASE {
		@
		OFF
	}

} ! END OF GET


REGRIB    ;   Regrib of data   ;   MARS
{
    
    CLASS 	
	{ 
		&_DUMMY&CLASS  
		OFF
	} = OFF
    

    TYPE
	{ 
		&_DUMMY&TYPE   
		OFF
	} = OFF


    STREAM
	{ 
		&_DUMMY&STREAM 
		OFF
	} = OFF
    

    MODEL
	{
		&_DUMMY&MODEL
		OFF
	} = OFF

    EXPVER
	{
		@
        "   
		OFF
    } = OFF
    

    LEVTYPE
	{ 
		&_DUMMY&LEVTYPE 
		OFF
	} = OFF
    
    LEVELIST 
    {
        OFF
        *   
    } = OFF
    
    PARAM 
    {
        &_DUMMY&PARAM
		OFF
    } = OFF
    
    DATE
    {
		&_DUMMY&DATE
		OFF
    } = OFF
    
    REFDATE 
	{
		&_DUMMY&DATE
    } = OFF

	HDATE 
	{ 
		&_DUMMY&DATE 
		ALL
	} = OFF

    TIME
    {
        *   
		OFF
    } = OFF

	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

    STEP
    {
        *   
		OFF
    } = OFF
    
    ANOFFSET
    {
        *   
		OFF
    } = OFF
    
    REFERENCE
    {
        *   
		OFF
    } = OFF 

    NUMBER
    {
        *   
        OFF
    } = OFF
    
    QUANTILE
    {
        *   
        OFF
    } = OFF

    DOMAIN
    {
	&_DUMMY&DOMAIN
	OFF
    } = OFF

    FREQUENCY
    {
        *   
        OFF
    } = OFF
    
    DIRECTION
    {
        OFF
        *   
    } = OFF
    
    DIAGNOSTIC
    {
        OFF
        *   
    } = OFF

    ITERATION
    {
        OFF
        *   
    } = OFF
    
    CHANNEL
	{ 
		&_DUMMY&CHANNEL 
	} = OFF

    IDENT
	{ 
		&_DUMMY&IDENT 
	} = OFF

    INSTRUMENT
	{ 
		&_DUMMY&INSTRUMENT 
	} = OFF

    ORIGIN
	{
		&_DUMMY&ORIGIN
	} = OFF

    MODEL
	{
		OFF
		ECMF
		EDZW
		EGRR
		LFPW
		KWBC
		NONE
	} = OFF

	SYSTEM { &_DUMMY&SYSTEM 
			  OFF } = OFF
	METHOD { &_DUMMY&METHOD 
			  OFF } = OFF
	PRODUCT { &_DUMMY&PRODUCT 
			  OFF } = OFF
	SECTION { &_DUMMY&SECTION 
			  OFF } = OFF
	LATITUDE { @ 
			   OFF } = OFF
	LONGITUDE { @ 
				OFF } = OFF

    OBSTYPE { @
				OFF } = OFF

    IDENT { @
        METEOSAT 3 ; MS3  ; 50
        METEOSAT 4 ; MS4  ; 51
        METEOSAT 5 ; MS5  ; 52
        METEOSAT 6 ; MS6  ; 53
        METEOSAT 7 ; MS7  ; 54
        GOES 8     ; GOES ; 252
		DMSP 10 ; 204
		DMSP 13 ; 246
		OFF } = OFF
    

	KSEC1 
	{
		OFF
		*
		@
		/
	} = OFF

	LOCALDEF
	{
		OFF
		*
		@
	} = OFF

    SOURCE
    {
		@
        "   
    } = ""

    TARGET
    {
		@
        "   
		OFF
    }= ""

} ! END OF REGRIB

!-----------------------------------------------------------------

ERASE    ;   Erase data   ;   MARS
{
    
	DATASET
	{
		@
	}

    CLASS
	{ 
		&_DUMMY&CLASS  
	} = TE
    

    TYPE
	{ 
		&_DUMMY&TYPE   
		*
	} = AN


    STREAM
	{ 
		&_DUMMY&STREAM 
		*
	} = MA
    

    EXPVER
	{
		@
		1
        "   
        *   
        /
    } = 9999
    

    MODEL
	{
		&_DUMMY&MODEL
	} = OFF

    REPRES
	{ 
		&_DUMMY&REPRES 
	} = SH
    
	OBSGROUP
	{ 
		&_DUMMY&OBSGROUP 
		OFF    ; OFF
	} = OFF
    
	RDBPREFIX
	{ 
		@
		"
		OFF    ; OFF
	} = OFF
    
    OBSTYPE
    {
        ALL                     ;   ALL
        NON SATELLITE DATA ALL  ;   NSD 
        SATELLITE DATA ALL      ;   SD
        &_DUMMY & OBSTYPE
    } = 0

    LEVTYPE
	{ 
		&_DUMMY&LEVTYPE 
	} = DP
    
    LEVELIST
    {
		TO ;    TO
		BY ;    BY 
        ALL ;   ALL
        OFF ;   OFF
        *   
        /   
    } = 9999
    
    PARAM 
    {
        ALL             
        &_DUMMY&PARAM
    } = 255
    
	YEAR 
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

	DECADE
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

	MONTH
	{
		*
		/
		TO
		BY  ;   BY           !        1
		ALL
	}

    DATE 
    {
		&_DUMMY&DATE
    } = 19000101
    
    VERIFY
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF
    
    REFDATE
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF

    HDATE
	{
		&_DUMMY&DATE
		OFF          ; OFF
    } = OFF

    FCMONTH
	{
		*
		/
		TO
		BY  ! 1
		OFF
    } = OFF
    
    FCPERIOD
    {
        TO  ;   TO
        BY  ;   BY    
		/
        *   
		OFF
    } = OFF
    
    TIME
    {
        *   
        /   
        TO  
        BY  !        6
		ALL 
		12
    } = 12

	LEADTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	OPTTIME
	{
		*
		/
		TO
		OFF
	} = OFF

	RANGE
	{
		*
		OFF; OFF
	} = OFF
    
    STEP
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
    } = 00
    
    ANOFFSET
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
		OFF
    }
    
    REFERENCE
    {
        ALL 
        *   
        /   
        TO  
        BY  !           12
		OFF
    } = OFF 

    NUMBER
    {
        ALL 
        OFF ;   OFF
		TO  
		BY
        *   
        /
    } = OFF
    
    QUANTILE
    {
        ALL ;   ALL
        OFF ;   OFF
		TO  ; TO
		BY
        *   
        /
    } = OFF

    DOMAIN
    {
	&_DUMMY&DOMAIN
    } = GLOBE

    FREQUENCY
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIRECTION
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    DIAGNOSTIC
    {
        ALL 
        OFF ;   OFF
        *   
        /
    } = OFF

    ITERATION
    {
        ALL 
        OFF ;   OFF
		TO
        *   
        /
    } = OFF
    
    CHANNEL
	{ 
		ALL
		&_DUMMY&CHANNEL 
	} = OFF

    IDENT
    {
		ALL 
		&_DUMMY&IDENT
		"
		@
    }=OFF
    
    ORIGIN
	{
		&_DUMMY&ORIGIN
	} = OFF

	SYSTEM { &_DUMMY&SYSTEM 
			  OFF } = OFF
	METHOD { &_DUMMY&METHOD 
			  OFF } = OFF
	PRODUCT { &_DUMMY&PRODUCT 
			  OFF } = OFF
	SECTION { &_DUMMY&SECTION 
			  OFF } = OFF
	LATITUDE { @ 
			   OFF } = OFF
	LONGITUDE { @ 
				OFF } = OFF

    SOURCE
    {
		@
        "   
		OFF
    } = ""

    TARGET
    {
		@
        "   
		OFF
    } = ""

    LOGSTATS
    {
		@
        "   
		OFF
    }

    TRANSFER
    {
		HANDLE
		DATA
		OFF
    }

    FIELDSET
    {
        @
		OFF
    }
    
    CFSPATH
    {
        "   
    } = ""
    
    FORMAT
    {
        PACKED      ;   P
        UNPACKED    ;   U
        GRIB EDITION 1 ;   GRIB1
        GRIB EDITION 2 ;   GRIB2
		NETCDF
    } = P
    
    DISP
    {
        NEW ;   N
        OLD ;   OLD
		REMOVE
		OFF
    } = OFF
    
    RESOL
    {
        ARCHIVED VALUE       ;   AV
		AUTOMATIC RESOLUTION ;   AUTO
		REDUCED GAUSSIAN 128 ;   N128
		REDUCED GAUSSIAN 200 ;   N200
		OFF                  ;   OFF
		319
		213
		106
		63
        *   
    } = AUTO
    
    ACCURACY
    {
        NORMAL  ;   N
        REDUCED ;   R
        LOW     ;   L
		OFF; OFF
        *   
		ARCHIVED VALUE ; AV
    } = N
    
    STYLE
    {
        DISSEMINATION  
        OFF   
    } = OFF
    
	INTERPOLATION
	{
		NEAREST NEIGHBOUR
        NEAREST LSM  
		BILINEAR
		LINEAR
		LINEAR FIT
		CUBIC
		AVERAGE WEIGHTED
		AVERAGE
		OFF
	} = OFF

    AREA
    {
        GLOBE                           ;   G
        EUROPE                          ;   E 
        NORTHERN HEMISPHERE OCTANT 1    ;   N1
        NORTHERN HEMISPHERE OCTANT 2    ;   N2
        NORTHERN HEMISPHERE OCTANT 3    ;   N3
        NORTHERN HEMISPHERE OCTANT 4    ;   N4
        SOUTHERN HEMISPHERE OCTANT 1    ;   S1
        SOUTHERN HEMISPHERE OCTANT 2    ;   S2
        SOUTHERN HEMISPHERE OCTANT 3    ;   S3
        SOUTHERN HEMISPHERE OCTANT 4    ;   S4
        *   
        /   
    } = G

	LOCATION
	{
		*
        /   
        OFF     ;  OFF
	} = OFF

    BLOCK
    {
        OFF     ;  OFF
        /   
        *       
    }=OFF

    INSTRUMENT
    {
		&_DUMMY&INSTRUMENT
    }=OFF

	ROTATION
	{
		*
		/
		OFF;  OFF
	} = OFF

	FRAME
	{
		*
		OFF;  OFF
	} = OFF

	BITMAP
	{
		OFF ; OFF
		@
		"
	}  = OFF

    GRID
    {
		ARCHIVED VALUE  ;   AV
		&_DUMMY&GRID
    } = OFF
    
	GAUSSIAN
	{
		REDUCED
		REGULAR
		OFF     ;  OFF
	} = OFF

	SPECIFICATION
	{
		*
		OFF
	} = OFF

	PACKING
	{
		SI   ; SIMPLE
		CO   ; COMPLEX
		SO   ; SECOND ORDER
		AV   ; ARCHIVED VALUE
		OFF
	} = OFF


    PADDING
    {
		&_DUMMY&PADDING
		OFF
    } = OFF
    

    DUPLICATES
    {
        KEEP
        REMOVE
    } = KEEP
    
    LAUNCH
    {
        "   
    } = ""
    
	JOB
	{
		"
		OFF
	} = OFF

    USE
    {
        FREQUENT   
        INFREQUENT
        NORMAL
		BOUNDARY CONDITIONS  ;  BC
		COMPARE
		MONTHLY RUN
    } = NORMAL
    
    PASSWORD
    {
        "   
		@
        OFF ;   OFF
    } = OFF
    
    COSTONLY
    {
        YES ;   Y
        NO  ;   N
    } = N
    
    PROCESS
    {
		LOCAL 
		SERVER
        OFF ;   OFF
    } = LOCAL

	BRANCH
	{ &_DUMMY&BRANCH } = OFF

	DATABASE
	{
		@
		/
		OFF
	} = marsdev

	EXPECT
	{
		ANY
		*
		OFF ; OFF
	} = OFF

	_VERSION
	{
		*
	} = 2.0
    
} ! END OF ERASE
